@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.75 $
+  $Revision: 1.89 $
 
   DBupdate 
 
@@ -11,7 +11,7 @@
   Modification History:
         engin (01/03/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2001                              RIPE NCC
 
   All Rights Reserved
 
@@ -68,6 +68,10 @@ int networkupdate = 0;
 /* IP of the networkupdate client */
 char * netupdclientIP = NULL;
 
+/* two global variables to tally the processed objects */
+int count_successful = 0;
+int count_unsuccessful = 0;
+
 
 /* sender of the mail, in case of a mail update */
 char *update_mail_sender = NULL;
@@ -81,6 +85,8 @@ char *tmpdir = NULL;
 char *lockdir = NULL;
 char *mailcmd = NULL;
 char *notitxt = NULL;
+char *successtxt = NULL;
+char *failuretxt = NULL;
 char *notimailtxt = NULL;
 char *notinetworktxt = NULL;
 char *fwtxt   = NULL;
@@ -122,6 +128,7 @@ char *cno_explain_add = NULL;
 char *cno_explain_del = NULL;
 char *cno_overlap_add = NULL;
 char *cno_overlap_del = NULL;
+char *allocmnt = NULL;
 char *mheader = NULL;
 char *DBhost = NULL;
 int  DBport;
@@ -198,7 +205,6 @@ char * delete_key(char * obj){
   /* get the certif first */
   certiflist = get_attr_list(obj, "certif");
   if(( key_file = fopen(tempfile, "w")) == NULL){
-     //fprintf(stderr, "Can't open temporary file, %s", tempfile);
      ER_perror(FAC_UP, UP_CANTOPEN, "Can't open temporary file, %s", tempfile);
      exit(1);
   }
@@ -221,7 +227,6 @@ char * delete_key(char * obj){
       }
     }
     g_strfreev(lines);
-    //fprintf(key_file, "%s\n", (char *)next->data);
   }
   fclose(key_file);
   g_slist_free(certiflist);
@@ -403,7 +408,7 @@ char * import_key(char *obj){
    be in the database (thus, in the keyring) 
    The fingerprint and keyowner will be saved in global variables */
    
-void * get_keyowner_fingerpr(char *obj){
+void get_keyowner_fingerpr(char *obj){
 
   GSList * templist = NULL;
   char * obj_keyID = NULL;
@@ -478,7 +483,6 @@ int process_object(char * incoming, credentials_struct credentials,
     char * old_version = NULL;
     o = new Object;
     int result = 0;
-    //int result_from_RIPupd = 0;
     up_ripupd_result_struct * result_from_RIPupd;
     char * result_from_import_key = NULL;
     char * result_from_delete_key = NULL;
@@ -491,6 +495,7 @@ int process_object(char * incoming, credentials_struct credentials,
     char * arg;
     char * arg2;
     char * generated_object;
+	char *search_key = NULL;
     external_syntax_struct * external_syntax_results;
 
 
@@ -505,7 +510,7 @@ int process_object(char * incoming, credentials_struct credentials,
          /* try to parse the object only for reporting purposes */
          o->scan_silent(arg,strlen(arg));
          AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] Unknown AUTO NIC handle referenced\n%s\n", 
-                 (o && o->type) ? o->type->getName() : "unknown-type", arg);
+                 (o && o->type) ? o->type->getName() : "unknown-type", delete_override(arg));
          delete(o);
          return UP_ANE; /* AUTO NIC hdl error */
          
@@ -525,14 +530,17 @@ int process_object(char * incoming, credentials_struct credentials,
       if(o->isDeleted){
         old_version = get_old_version(arg);
         if(old_version == NULL){ /* the object doesn't exist in the db! */
-          AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\nEntry not found\n\n%s\n", 
-                        o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+		    search_key = get_search_key(o, o->type->getName(), arg);
+			if ( search_key == NULL )
+			  search_key = "";
+          AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n***Error: Entry not found\n\n",
+                        o->type->getName(), search_key, delete_override(arg));
           return UP_NSO; /* no such object */
         }else {/* the object is in the db */
           if(identical(old_version, arg) /* if the old & new versions are identical */
              || (strcmp(o->type->getName(), "key-cert") == 0)  /* or it is a key-cert object  */
              || (strcmp(o->type->getName(), "inet6num") == 0)){/* or it is an inet6num object */
-            result = check_auth(NULL, old_version, o->type->getName(), credentials);
+            result = check_auth(NULL, arg, o->type->getName(), credentials);
             if(result == UP_AUTH_OK){ 
               if(tracing) {
                 printf("TRACING: Will send the obj to be deleted\n");
@@ -550,15 +558,19 @@ int process_object(char * incoming, credentials_struct credentials,
                                 o->type->getName(), get_search_key(o, o->type->getName(), arg));
                   NT_write_all_ntfs(old_version, NULL, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, 
                                     credentials.from);
+                  return UP_OK;
                 }else{
                   AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n",
                                 o->type->getName(), get_search_key(o, o->type->getName(), arg),
                                 result_from_RIPupd->error_str);
+                  return UP_INT;
                 }
                 result_from_RIPupd->result = 0;
               }else{
                  AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n",
-                                o->type->getName(), get_search_key(o, o->type->getName(), arg), result_from_delete_key);
+                                o->type->getName(), get_search_key(o, o->type->getName(), delete_override(arg)),
+                                result_from_delete_key);
+                 return UP_INT;
               }
             }else{ /* auth failed */
               if(tracing) {
@@ -566,13 +578,13 @@ int process_object(char * incoming, credentials_struct credentials,
               }
 
               AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\nAuthorisation failed, request forwarded to maintainer.\n%s\n",
-                            o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                            o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
               NT_write_all_frwds(arg, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
               return UP_AUF; /* Auth failed */
             } 
           }else{/* the new & old versions do not match */
-            AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\nnew & old versions do not match\n%s\n",
-                 o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+            AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n***Error: new & old versions do not match\n",
+                 o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
             return UP_NOM; /* new & old versions do not match */
           }
         }
@@ -607,23 +619,27 @@ int process_object(char * incoming, credentials_struct credentials,
                 arg2 = delete_override(arg);
                 NT_write_all_ntfs(NULL, arg2, formatted_object, tmpdir, ntfy_hash, forw_hash, cross_hash, 
                                   credentials.from);
+                
+                result_from_RIPupd->result = 0;
+                if(tracing && assigned_NIC != NULL) {  
+                  printf("TRACING: send_object_db returned [%s] as assigned NIC hdl\n", assigned_NIC);
+                }
+                if(assigned_NIC != NULL){
+                  if(tracing){
+                    printf("TRACING: auto_nic=[%s], assigned_NIC=[%s]\n", auto_nic, assigned_NIC);
+                  }
+                  g_hash_table_insert(NIC_hdl_hash, auto_nic, assigned_NIC);
+                  if(tracing){
+                    printf("TRACING: NIC_hdl_hash has %i pairs\n",g_hash_table_size(NIC_hdl_hash));
+                  }
+                }
+                
+                return UP_OK;
               }else{
                 AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s]\n%s\n%s\n",
-                              o->type->getName(), arg,
+                              o->type->getName(), delete_override(arg),
                               result_from_RIPupd->error_str);
-              }
-              result_from_RIPupd->result = 0;
-              if(tracing && assigned_NIC != NULL) {  
-                printf("TRACING: send_object_db returned [%s] as assigned NIC hdl\n", assigned_NIC);
-              }
-              if(assigned_NIC != NULL){
-                if(tracing){
-                  printf("TRACING: auto_nic=[%s], assigned_NIC=[%s]\n", auto_nic, assigned_NIC);
-                }
-                g_hash_table_insert(NIC_hdl_hash, auto_nic, assigned_NIC);
-                if(tracing){
-                  printf("TRACING: NIC_hdl_hash has %i pairs\n",g_hash_table_size(NIC_hdl_hash));
-                }
+                return UP_INT;
               }
               
             }else{
@@ -633,7 +649,7 @@ int process_object(char * incoming, credentials_struct credentials,
               }
   
               AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\nAuthorisation failed, request forwarded to maintainer.\n%s\n",
-                            o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                            o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
               arg2 = delete_override(arg);
               NT_write_all_frwds(NULL, arg2, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
               return UP_AUF; /* Auth failed */
@@ -641,7 +657,8 @@ int process_object(char * incoming, credentials_struct credentials,
           }else{/* external syntax check failed */
             AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s%s\n",
                    o->type->getName(), get_search_key(o, o->type->getName(), arg), 
-                   arg, external_syntax_results->error_str);
+                   delete_override(arg), external_syntax_results->error_str);
+            return UP_SYN;
           }
         }
         else{ 
@@ -674,21 +691,35 @@ int process_object(char * incoming, credentials_struct credentials,
                       arg2 = delete_override(arg);
                       NT_write_all_ntfs(old_version, arg2, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, 
                                         credentials.from);
+                      return UP_OK;
                     }else{
-                      AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s\n",
-                      
+                      AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s\n%s\n",
                                     o->type->getName(), get_search_key(o, o->type->getName(), arg),
-                                    result_from_RIPupd->error_str);
+                                    delete_override(arg), result_from_RIPupd->error_str);
+                      return UP_INT;
                     }
                     result_from_RIPupd->result = 0;
-                  }else{
+                  }else if(result == UP_NAM){
+                    /* name of a person/role object cannot be changed */
+                    if(tracing) {
+                      printf("TRACING: name of a person/role object cannot be changed\n");
+                    }
+                    
+                    AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s\n***Error: Name of a person or role object cannot be changed.\n",
+                                  o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
+                    arg2 = delete_override(arg);
+                    return UP_NAM; /* name of a person/role object cannot be changed */
+
+
+                  }
+                  else{
                     /* auth failed ! */
                     if(tracing) {
                       printf("TRACING: Auth failed\n");
                     }
       
                     AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\nAuthorisation failed, request forwarded to maintainer.\n%s\n",
-                                  o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                                  o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
                     arg2 = delete_override(arg);
                     NT_write_all_frwds(old_version, arg2, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
                     return UP_AUF; /* Auth failed */
@@ -700,20 +731,23 @@ int process_object(char * incoming, credentials_struct credentials,
                   }
                   AK_add_to_ack(ack_file_name, "\nUpdate NOOP: [%s] %s\n",
                                     o->type->getName(), get_search_key(o, o->type->getName(), arg));
+                  return UP_OK;
    
                 }
               }else{/* if there is an error in external syntax checks */
                 AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s%s\n",
                      o->type->getName(), get_search_key(o, o->type->getName(), arg), 
-                     arg, external_syntax_results->error_str);
+                     delete_override(arg), external_syntax_results->error_str);
+                return UP_SYN;
               }
 
             }else{/* if the user enforced creation (using NEW keyword) in the subject line */
 
               AK_add_to_ack(ack_file_name, "\nUpdate FAILED: [%s] %s\n%s\n"
-                   "***ERROR:  Object already exists\n",
+                   "***Error:  Object already exists\n",
                    o->type->getName(), get_search_key(o, o->type->getName(), arg), 
-                   arg);
+                   delete_override(arg));
+              return UP_INT;
               
             }
           }else { /* old_version  == NULL, so, creation */
@@ -747,18 +781,20 @@ int process_object(char * incoming, credentials_struct credentials,
                     arg2 = delete_override(arg);
                     NT_write_all_ntfs(NULL, arg2, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, 
                                       credentials.from);
+                    return UP_OK;
 
                   }else{
-                    //AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\nReferential integrity failure\n",
                     AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\n%s\n",
                                   o->type->getName(), get_search_key(o, o->type->getName(), arg),
                                   result_from_RIPupd->error_str);
+                    return UP_INT;
                   }
                   result_from_RIPupd = 0;
                 }else{/* there was a problem with PGP key import */
                   AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\n%s\n",
                                   o->type->getName(), get_search_key(o, o->type->getName(), arg),
                                   result_from_import_key);
+                  return UP_INT;
                 }
               }else if(result == UP_FWD){ /* this was a maintainer or as-block creation request, so
                                              forward it to <HUMAILBOX> */
@@ -770,23 +806,27 @@ int process_object(char * incoming, credentials_struct credentials,
                 }
 
                 AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\n%s\n"
-                              "*ERROR*:     %s objects cannot be created automatically\n"
-                              "*ERROR*:     This object has been forwarded to %s\n"
-                              "*ERROR*:     for authorisation.\n"
-                              "*ERROR*:     No further action from your part is required\n",
+                              "***Error:     %s objects cannot be created automatically\n"
+                              "***Error:     This object has been forwarded to %s\n"
+                              "***Error:     for authorisation.\n"
+                              "***Error:     No further action from your part is required\n",
                               o->type->getName(), get_search_key(o, o->type->getName(), arg),
-                              external_syntax_results->new_obj, o->type->getName(), humailbox);
+                              delete_override(external_syntax_results->new_obj), o->type->getName(), humailbox);
 
                 /* and forward this creation request to <HUMAILBOX> */
                 NT_forw_create_req(external_syntax_results->new_obj);
+
+                return UP_AUF;
+
                 
               }else if(result == UP_HOF){/* hierarchical authorisation failed */
                 if(tracing) {
                   printf("TRACING: Auth failed\n");
                 }
 
-                AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\nHierarchical authorisation failed, request forwarded to maintainer.\n%s\n",
-                              o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\n%s\n***Error: Hierarchical authorisation"
+                              " failed, request forwarded to maintainer.\n",
+                              o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
                 arg2 = delete_override(arg);
                 NT_write_all_frwds(NULL, arg2, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
                 return UP_AUF;
@@ -799,7 +839,7 @@ int process_object(char * incoming, credentials_struct credentials,
                 }
 
                 AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\nAuthorisation failed, request forwarded to maintainer.\n%s\n",
-                              o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                              o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
                 arg2 = delete_override(arg);
                 NT_write_all_frwds(NULL, arg2, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
                 return UP_AUF; /* Auth failed */
@@ -807,7 +847,8 @@ int process_object(char * incoming, credentials_struct credentials,
             }else{
               AK_add_to_ack(ack_file_name, "\nNew FAILED: [%s] %s\n%s%s\n",
                               o->type->getName(), get_search_key(o, o->type->getName(), arg), 
-                              arg, external_syntax_results->error_str);
+                              delete_override(arg), external_syntax_results->error_str);
+              return UP_SYN;
             }
           } 
         }
@@ -823,8 +864,11 @@ int process_object(char * incoming, credentials_struct credentials,
          /* here delete it */
          old_version = get_old_version(arg);
          if(old_version == NULL){ /* the object doesn't exist in the db! */
-            AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\nEntry not found\n\n%s\n", 
-                          o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+		    search_key = get_search_key(o, o->type->getName(), arg);
+			if ( search_key == NULL )
+			  search_key = "";
+            AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n***Entry not found\n\n", 
+                          o->type->getName(), search_key, delete_override(arg));
             return UP_NSO; /* no such object */
           }else {/* the object is in the db */
             if(identical(old_version, arg)){/* if the old & new versions are identical */
@@ -846,15 +890,18 @@ int process_object(char * incoming, credentials_struct credentials,
                                   o->type->getName(), get_search_key(o, o->type->getName(), arg));
                     NT_write_all_ntfs(arg, NULL, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, 
                                       credentials.from);
+                    return UP_OK;
                   }else{
                     AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n",
                                   o->type->getName(), get_search_key(o, o->type->getName(), arg),
                                   result_from_RIPupd->error_str);
+                    return UP_INT;
                   }
                   result_from_RIPupd = 0;
                 }else{
                    AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\n%s\n",
                                   o->type->getName(), get_search_key(o, o->type->getName(), arg), result_from_delete_key);
+                   return UP_INT;
                 }
               }else{ /* auth failed */
                 if(tracing) {
@@ -862,12 +909,12 @@ int process_object(char * incoming, credentials_struct credentials,
                 }
 
                 AK_add_to_ack(ack_file_name, "\nDelete FAILED: [%s] %s\nAuthorisation failed, request forwarded to maintainer.\n%s\n",
-                              o->type->getName(), get_search_key(o, o->type->getName(), arg), arg);
+                              o->type->getName(), get_search_key(o, o->type->getName(), arg), delete_override(arg));
                 NT_write_all_frwds(arg, NULL, tmpdir, ntfy_hash, forw_hash, cross_hash, credentials.from);
                 return UP_AUF; /* Auth failed */
               } 
             }else{/* the new & old versions do not match */
-              AK_add_to_ack(ack_file_name, "\nDelete FAILED: new & old versions do not match\n%s\n", arg);
+              AK_add_to_ack(ack_file_name, "\nDelete FAILED: new & old versions do not match\n%s\n", delete_override(arg));
               return UP_NOM; /* new & old versions do not match */
             }
           }
@@ -877,16 +924,17 @@ int process_object(char * incoming, credentials_struct credentials,
        
          if(o->attrs.head() != NULL){
            for(attr = o->attrs.head(); attr; attr = o->attrs.next(attr)){
-             if(attr->len > 0){
-               value = (char*)malloc(attr->len);
-               strncpy(value, (char *)(arg+attr->offset) ,
-                 attr->len - 1);
-               value[attr->len - 1] = '\0';
-               AK_add_to_ack(ack_file_name, "%s\n", value);
-               if(!attr->errors.empty()){
-                 AK_add_to_ack_string(ack_file_name, attr->errors);
-               }
-               free(value);
+             if(attr->len > 0 && 
+                ( attr->type == NULL || (attr->type != NULL && strcasecmp(attr->type->name(), "override") != 0)) ){
+                 value = (char*)malloc(attr->len);
+                 strncpy(value, (char *)(arg+attr->offset) ,
+                   attr->len - 1);
+                 value[attr->len - 1] = '\0';
+                 AK_add_to_ack(ack_file_name, "%s\n", value);
+                 if(!attr->errors.empty()){
+                   AK_add_to_ack_string(ack_file_name, attr->errors);
+                 }
+                 free(value);
              }else{
                if(!attr->errors.empty()){
                  AK_add_to_ack_string(ack_file_name, attr->errors);
@@ -990,25 +1038,42 @@ struct VerifySignObject vSO, *pvSO;
     next = list_of_objects;
     object_count = 0;
     for( next = list_of_objects; next != NULL ; next = g_slist_next(next) ){
-      object_count++;
-
-      if(tracing) {
-        cout << "TRACING: Got an object from the list" << endl;
-        cout << (char *)next->data << endl;
-      }
       
-      if(has_ref_to_AUTO_nic_hdl((char *)next->data)){/* defer the processing */
+      if(UP_is_object((char *)next->data)){/* if this looks like an object */
+      
+        object_count++;
+
         if(tracing) {
-          printf("TRACING: this object has a ref to an AUTO NIC hdl\n");
+          cout << "TRACING: Got an object from the list" << endl;
+          cout << (char *)next->data << endl;
         }
-        list_of_objects2 = g_slist_append(list_of_objects2, strdup((char *)next->data));
-      }else{
-        result = 0;
-        result = process_object((char *)next->data, credentials, AUTO_NIC_hdl_hash, ack_file_name, 
-                                 ntfy_hash, forw_hash, cross_hash);
+        
+        if(has_ref_to_AUTO_nic_hdl((char *)next->data)){/* defer the processing */
+          if(tracing) {
+            printf("TRACING: this object has a ref to an AUTO NIC hdl\n");
+          }
+          list_of_objects2 = g_slist_append(list_of_objects2, strdup((char *)next->data));
+        }else{
+          result = 0;
+          result = process_object((char *)next->data, credentials, AUTO_NIC_hdl_hash, ack_file_name, 
+                                   ntfy_hash, forw_hash, cross_hash);
+          /* keep a tally */
+          if(result == UP_OK){
+            count_successful++;
+          }else{
+            count_unsuccessful++;
+          }
+        
+        }
+      }else{/* this does not look like an object (a signature? some other text?) */
+        
+        AK_add_to_ack(ack_file_name, "\nThe following paragraph does not look like an object,\n"
+                                     "so ignoring it:\n%s\n", (char *)next->data);
+        
       }
     }
 
+
     if(tracing) {
       printf("TRACING: list_of_objects2 has %d entries\n", g_slist_length(list_of_objects2));
     }
@@ -1023,6 +1088,13 @@ struct VerifySignObject vSO, *pvSO;
       }
       result = process_object((char *)next->data, credentials, AUTO_NIC_hdl_hash, ack_file_name, 
                                ntfy_hash, forw_hash, cross_hash);
+        /* keep a tally */
+        if(result == UP_OK){
+          count_successful++;
+        }else{
+          count_unsuccessful++;
+        }
+      
     }
   
 }/* process_file */
@@ -1242,10 +1314,6 @@ void main(int argc, char **argv, char **envp){
 
   long debug = 0;
     
-  /* optarg & optind are necessary to use getopt(3C) */ 
-  extern char *optarg;
-  extern int optind;
-
 
   /* create notification hashes */
   ntfy_hash = g_hash_table_new(g_str_hash, g_str_equal);
@@ -1322,6 +1390,8 @@ void main(int argc, char **argv, char **envp){
   mailcmd = g_strstrip(mailcmd);
   notitxt = ca_get_notitxt;
   mailtxt = ca_get_mailtxt; 
+  successtxt = ca_get_successtxt;
+  failuretxt = ca_get_failuretxt;
   defmail = ca_get_defmail; defmail = UP_remove_EOLs(defmail);
   crosslog = ca_get_crosslog;
   fwtxt = ca_get_fwtxt;
@@ -1344,6 +1414,13 @@ void main(int argc, char **argv, char **envp){
   pgppath = ca_get_pgppath;
   gpgcmd = ca_get_gpgcmd;
   autodbmhelp = ca_get_autodbmhelp;
+  allocmnt = ca_get_allocmnt; allocmnt = UP_remove_EOLs(allocmnt);
+  /* convert all '\t's, '\n's and '\r's in allocmnt to white spaces */
+  for(i=0;i<strlen(allocmnt);i++){
+    if(allocmnt[i] == '\r' || allocmnt[i] == '\n' || allocmnt[i] == '\t'){
+      allocmnt[i] = ' ';
+    }
+  }
   cn_subject_add = ca_get_cn_subject_add; cn_subject_add = UP_remove_EOLs(cn_subject_add);
   cn_subject_del = ca_get_cn_subject_del; cn_subject_del = UP_remove_EOLs(cn_subject_del);
   cn_explain_add = ca_get_cn_explain_add;
@@ -1489,18 +1566,46 @@ void main(int argc, char **argv, char **envp){
     /* the new stuff using the EP module's interface */
     if(tracing){
       printf("\nTRACING: From field is: [%s]\n", p->from->field);
+      if(p->from->next != NULL){
+        printf("TRACING: From field (second line) is: [%s]\n", p->from->next->field);
+      }
     }
 
     temp = (char *)malloc(strlen(p->from->field) + strlen("From: ") + 1);
     sprintf(temp, "From: %s", p->from->field);
     /* cut off the '\n's and '\r's at the end of temp */
     UP_remove_EOLs(temp);
+
+    /* now, there is a problem with EP module (or c-client): the p->from->field
+       would contain only the first line if the "From" field has multiple lines.
+       As a temp solution, we will add the second line (if it exists) explicitely */
+    if(p->from->next != NULL){/* if the second line exists */
+      temp = (char *)realloc(temp, strlen(temp) + strlen(p->from->next->field) + 2);
+      snprintf(temp, strlen(temp) + strlen(p->from->next->field) + 2, 
+        "%s %s", temp, p->from->next->field);
+    }
+    UP_remove_EOLs(temp);
+    
     
     credentials.from = temp;
-    credentials.from_email = strdup(p->from->field);
+    credentials.from_email = strdup(p->from->field); /* This doesn't contain "From:" */
+    if(p->from->next != NULL){ /* if the second line exists */
+      credentials.from_email = (char *)realloc(credentials.from_email, strlen(credentials.from_email) +
+             strlen(p->from->next->field) + 2);
+      snprintf(credentials.from_email, strlen(credentials.from_email) + 
+             strlen(p->from->next->field) + 2, 
+        "%s %s", credentials.from_email, p->from->next->field);
+    }
+    UP_remove_EOLs(credentials.from_email);
 
-    update_mail_sender = strdup(p->from->field); 
+
+    update_mail_sender = strdup(credentials.from_email); 
     update_mail_sender = UP_remove_EOLs(update_mail_sender);
+    
+    if(tracing){
+      printf("\nTRACING: update_mail_sender is: [%s]\n", update_mail_sender);
+    }
+    
                
     if(p->subject != NULL && p->subject->field != NULL){
       subject = strdup(p->subject->field);
@@ -1528,7 +1633,6 @@ void main(int argc, char **argv, char **envp){
     UP_remove_EOLs(reply_to);
 
     
-
     to_address = find_email_address(credentials.from);
 
     /* if Reply_To was available in the incoming header, then use it */
@@ -1579,10 +1683,6 @@ void main(int argc, char **argv, char **envp){
     /* If this wasn't only a help request, then we need to process the input */
     if(subject_result.result != UP_SUBJ_HELP_REQ){
       
-      /* Print out the header of the ackonwledgement */
-      AK_add_to_ack(ack_file_name, "To: %s\n%s\n\nAcknowledgement message from"
-        " database software\n\n%s\n", to_address, mheader_replaced, mailtxt_replaced);
-
       /* ... and now process the items in the list */
       list_item = pt;
       while (list_item != NULL) {
@@ -1691,7 +1791,7 @@ void main(int argc, char **argv, char **envp){
   }  
 
 
-  /* send the ack */
+  /* post-process and send the ack */
   if(reading_from_mail && to_address != NULL){
     AK_send_ack(ack_file_name, to_address, mailcmd);
   }
@@ -1725,7 +1825,8 @@ void main(int argc, char **argv, char **envp){
   /* remove checkpoint file */
   remove_checkpoint();
 
-     
+
+
   if(tracing) {
     printf("TRACING: END\n");
   }
