@@ -1,9 +1,9 @@
 #!/bin/sh
 check_error()
 {
-	if [ $1 -ne 0 ] 
+	if [ $2 -ne 0 ] 
 	then
-	echo "loader failure [$1]. Exiting\n"
+	echo "*** ERROR: $1 [$2]. Exiting\n"
 	exit 1
 fi
 
@@ -15,17 +15,21 @@ loadpass()
   for object_file in ${LIST} 
   do
     echo `date` Loading ${object_file} 
-    ${UNZIP1} ${object_file} | eval ${FILTER} | ./loader -L $1 -p ${PROPERTIES} -s ${SOURCE}
-    check_error $?
+    test -f ${object_file}
+    check_error "${object_file} not found" $?
+    ${UNZIP1} ${object_file} | eval ${FILTER} | $LOADER -L $1 -p ${PROPERTIES} -s ${SOURCE}
+    check_error "Loader failure" $?
   done
 }
 
+# switch on debugging (set -x)
+$DEBUG
+
 # number of passes to load the db
 # 0  means do not load data (empty_db)
 # 1 means single pass, 2 means 2-pass loading
 NPASSES=$1
 NPASSES=${NPASSES:?"Usage $0 npasses"}
-set -x
 echo "*******************"`date`"******************" 
 echo "Creating tables\n" 
 echo "Creating tables\n"
@@ -38,7 +42,7 @@ then
   echo "Loading tables - I pass\n"
 
   loadpass 1 
-  check_error $?
+  check_error "Pass I failed" $?
 fi
 
 echo `date`"\n" 
@@ -52,7 +56,7 @@ then
   echo "Loading tables - II pass\n"
 
   loadpass 2
-  check_error $?
+  check_error "Pass II failed" $?
 fi
 
 echo `date`"\n"
@@ -67,7 +71,7 @@ then
   echo "Loading tables \n"
 
   loadpass 0
-  check_error $?	
+  check_error "Loading failed" $?	
 fi
 
 echo "Finished "`date`
