@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.42 $
+  $Revision: 1.44 $
 
   Access control module (ac) - access control for the query part
 
@@ -8,7 +8,7 @@
   Design and implementation by: Marek Bukowy
   
   ******************/ /******************
-  Copyright (c) 1999                              RIPE NCC
+  Copyright (c) 1999,2000,2001                              RIPE NCC
  
   All Rights Reserved
   
@@ -36,27 +36,19 @@
       
 */
 
+#define AC_IMPL
+#include "rip.h"
+
 #include <stdio.h>
 #include <glib.h>
 #include <string.h>
+#include <math.h>
 
-#define AC_IMPL
-#include "rxroutines.h"
-#include "erroutines.h"
-#include "access_control.h"
-#include "sk.h"
-#include "ta.h"
-#include "mysql_driver.h"
-#include "constants.h"
-#include "server.h"
+#include <unistd.h>
+#include <stdlib.h>
 
-#include "ca_configFns.h"
-#include "ca_dictionary.h"
-#include "ca_macros.h"
-#include "ca_srcAttribs.h"
-#include "timediff.h"
-
-#include "math.h" /* exp() */
+extern char *suboptarg;
+extern int getsubopt(char **optionp, char * const *tokens, char **valuep);
 
 /* formats for printing the access control list entries */
 #define ACL_FORMAT        "%10d %10d %10d %10d %10d"
