@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.13 $
+  $Revision: 1.16 $
 
   AK (Acknowledgement) module
 
@@ -36,11 +36,15 @@
 #include "ack.h"
 extern int supress_ack_notif;
 extern char * humailbox;
+extern char * failuretxt;
+extern char * successtxt;
 extern char * defmail;
 extern char * acksig;
 extern int * reading_from_mail;
 extern int networkupdate;
 extern up_subject_struct subject_result;
+extern int count_successful;
+extern int count_unsuccessful;
 
 /*
 
@@ -208,7 +212,7 @@ char * AK_ack_file_name_generate( const char * tmpdir, const char * prefix){
 
 /* 
 
-AK_send_ack: sends the ack message contained in the temp file.
+AK_send_ack: post-processes and sends the ack message contained in the temp file.
  
    
 */
@@ -216,8 +220,9 @@ AK_send_ack: sends the ack message contained in the temp file.
 void AK_send_ack( const char * filename, const char * to_address, const char * mailercommand){
 
     char * mail_command_line = NULL;
-    char * supress_file = NULL;
-    FILE * ack_file, * supr_file_hdl;
+    char * supress_file = NULL, * temp_file = NULL;
+    FILE * ack_file, * supr_file_hdl, * temp_file_hdl;
+    char * failuretxt_replaced, *successtxt_replaced;
     char buf[1025];
 
 
@@ -260,10 +265,80 @@ void AK_send_ack( const char * filename, const char * to_address, const char * m
     }
 
 
+    /* if the update didn't contain any objects, put a warning */
+    if(count_successful == 0 && count_unsuccessful == 0){
+      AK_add_to_ack(filename, "*** Warning: No objects were found in the message ***\n");
+    }
+
     /* add the ACKSIG to the ack */
     AK_add_to_ack(filename ,"\n%s", acksig);
 
 
+    /* Here, we will print out the header of the ACK message. It cannot be
+       prepared before, since we wouldn't know if the header should use
+       SUCCESSTXT or FAILURETXT */
+    if(count_unsuccessful > 0 || (count_successful + count_unsuccessful) == 0){
+    /* so, at least one of objects failed or there wasn't any object in the
+       update message. We will use FAILURETXT */
+       temp_file = (char *)malloc(strlen(filename) + strlen(".temp") + 2);
+       sprintf(temp_file, "%s.temp", filename);
+       if(( temp_file_hdl = fopen(temp_file, "w")) == NULL){
+         fprintf(stderr, "Can't open temp ack file, %s\n", temp_file);
+       }else{
+         /* replace the global variables in failuretxt */
+         failuretxt_replaced = UP_replace_globals(failuretxt);
+         /* print out the failuretxt */ 
+         fprintf(temp_file_hdl, "To: %s\n%s\n\n", to_address, failuretxt_replaced);
+         free(failuretxt_replaced);
+         /* and now copy over the rest of the ack message */
+         if(( ack_file = fopen(filename, "r")) == NULL){
+           fprintf(stderr, "Can't open ack file for reading, %s", filename);
+         }else{
+           while(fgets(buf, 1024, ack_file) != NULL){
+             fprintf(temp_file_hdl, "%s", buf);
+           }
+           fclose(ack_file);
+         
+         }
+         fclose(temp_file_hdl);
+         /* and copy rename the temp file  */
+         rename(temp_file, filename);
+         free(temp_file);
+       }
+     }else{
+       /* so, all the objects in the update message were successful. So, we will
+          use SUCCESSTXT */
+       temp_file = (char *)malloc(strlen(filename) + strlen(".temp") + 2);
+       sprintf(temp_file, "%s.temp", filename);
+       if(( temp_file_hdl = fopen(temp_file, "w")) == NULL){
+         fprintf(stderr, "Can't open temp ack file, %s\n", temp_file);
+       }else{
+         /* replace the global variables in successtxt */
+         successtxt_replaced = UP_replace_globals(successtxt);
+         /* print out the successtxt */ 
+         fprintf(temp_file_hdl, "To: %s\n%s\n\n", to_address, successtxt_replaced);
+         free(successtxt_replaced);
+         /* and now copy over the rest of the ack message */
+         if(( ack_file = fopen(filename, "r")) == NULL){
+           fprintf(stderr, "Can't open ack file for reading, %s", filename);
+         }else{
+           while(fgets(buf, 1024, ack_file) != NULL){
+             fprintf(temp_file_hdl, "%s", buf);
+           }
+           fclose(ack_file);
+         
+         }
+         fclose(temp_file_hdl);
+         /* and copy rename the temp file  */
+         rename(temp_file, filename);
+         free(temp_file);
+       }
+          
+     }
+
+
+
+
 
     /* if we are not supressing acks and notifs, send the ack */
     if(!supress_ack_notif){
