@@ -13,7 +13,7 @@ Modification History:
 ******************/
 
 /************************************
- Copyright (c) 2000                              RIPE NCC
+ Copyright (c) 2000,2001                              RIPE NCC
 
 All Rights Reserved
 
@@ -34,17 +34,12 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 ***************************************/
 
 #define DICT_INIT
+#include "rip.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <glib.h>
 #include <string.h>
-#include <stubs.h>
-#include "ca_defs.h"
-#include "ca_dictionary.h"
-#include "ca_configFns.h"
-#include  <memwrap.h>
-#include <erroutines.h>
 #include <unistd.h>
 
 /* #define DEBUG */
@@ -1883,7 +1878,6 @@ ca_srchandle2Strelement(ca_SrcHdl_t * ah, int srcAttrib)
  *******************************************************************/
 {
 	char *myStr;
-	void ca_malloc(char *, int);
 
 	if (ah == NULL) {
 		fprintf(stderr, "ca_srchandle2Strelement(): Cannot dereference NULL pointer\n");
@@ -1942,7 +1936,7 @@ ca_srchandle2Strelement(ca_SrcHdl_t * ah, int srcAttrib)
 
 	default:
 		puts("Cannot find this source attribute");
-		break;
+                myStr = NULL;
 	}
 	pthread_mutex_unlock(&Lock);
 
@@ -2011,7 +2005,6 @@ ca_srchandle2Intelement(ca_SrcHdl_t * ah, int srcAttrib)
 	default:
 		fprintf(stderr, "Could not find source-attribute %d\n", srcAttrib);
 		die;
-		break;
 	}
 
 	pthread_mutex_unlock(&Lock);
@@ -2042,7 +2035,6 @@ ca_get_adminStrElement(int symbol, int adminAttrib)
  *******************************************************************/
 {
 	char *myStr;
-	void ca_malloc(char *, int);
 
 	/*
 	 * Make sure that we are calling the correct function.
@@ -2077,7 +2069,6 @@ ca_get_adminStrElement(int symbol, int adminAttrib)
 		default:
 			puts("Cannot find this admin attribute");
 			die;
-			break;
 		}
 		pthread_mutex_unlock(&Lock);
 
@@ -2103,40 +2094,12 @@ ca_get_adminIntElement(int symbol, int adminAttrib)
 	default:
 		puts("Cannot find this admin attribute");
 		die;
-		break;
 	}
 	pthread_mutex_unlock(&Lock);
 
 	return (myInt);
 }
 
-void
-ca_malloc(char *someStr, int memSize)
-/*******************************************************************
-  * ca_malloc                                      *
-  *  -- a function that allocates memory for a string          *
-  *                                            *
- * Parameters                                    *
-  * --someStr  - the string that is to be created              *
-  *   memSize- required amount of memory in bytes              *
-  *                                            *
-  * Returns                                      *
-  * -- nothing; it assigns the allocated memory to the pointer     *
- *   that was passed to it.                            *
-  *                                            *
-  *******************************************************************/
-{
-	someStr = malloc(memSize);
-
-	/*
-	 * Check that we actually did get the memory ....
-	 */
-	if (someStr == NULL) {
-		fprintf(stderr, "ca_malloc(): cannot allocate memory !!!\n");
-		exit(8);
-	}
-}
-
 void
 ca_set_boolean(int symbol)
 {
@@ -2563,7 +2526,7 @@ ca_set_dirlist(int symbol)
 
 	default:
 		fprintf(stderr, "Error: Unknown scope: %d\n", dictionary[symbol].varScope);
-		break;
+		die;
 	}
 
 
@@ -2627,6 +2590,11 @@ ca_set_dirlist(int symbol)
 }
 
 
+#if 0
+
+XXX: Unused function?  Removed because it causes warnings due to gets() 
+     invokation.  - Shane
+
 void
 ca_set_string(int symbol)
 {
@@ -2715,7 +2683,7 @@ ca_set_string(int symbol)
 
 	default:
 		fprintf(stderr, "Error: Unknown scope: %d\n", dictionary[symbol].varScope);
-		break;
+		die;
 	}
 
 
@@ -2782,6 +2750,7 @@ g_string_assign(hereValues[symbol].strPtr, newString);
 	 */
 
 }
+#endif /* 0 */
 
 
 int
@@ -3321,7 +3290,7 @@ ca_UpdSrcHandle2StrElement(ca_updDbSource_t * uh, int srcAttrib)
 
 	default:
 		puts("Cannot find this Update source attribute");
-		break;
+		myStr = NULL;
 	}
 
 	return (myStr);
@@ -3375,7 +3344,6 @@ ca_UpdSrcHandle2IntElement(ca_updDbSource_t * uh, int srcAttrib)
 	default:
 		fprintf(stderr, "Could not find source-attribute %d\n", srcAttrib);
 		die;
-		break;
 	}
 
 	return (myInt);
