@@ -14,7 +14,7 @@ Modification History:
 ******************/
 
 /************************************
-Copyright (c) 2000                              RIPE NCC
+Copyright (c) 2000,2001                         RIPE NCC
 
 All Rights Reserved
 
@@ -34,13 +34,13 @@ AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 ***************************************/
 
+#include "rip.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <glib.h>
 #include <string.h>
-#include <stubs.h>
 #include <unistd.h>
-#include "ca_configFns.h"
 
 /* #define DEBUG */	/* Swich OFF Debugging. */
 
