@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.29 $
+  $Revision: 1.33 $
 
   IP handling (ip). ip.c  - conversions between ascii and binary forms 
                             of IP addresses, prefixes and ranges.
@@ -11,7 +11,7 @@
   Design and implementation by: Marek Bukowy
 
   ******************/ /******************
-  Copyright (c) 1999                              RIPE NCC
+  Copyright (c) 1999,2000,2001                    RIPE NCC
  
   All Rights Reserved
   
@@ -32,22 +32,23 @@
   ***************************************/
 
 #define IP_IMPL
-#include <iproutines.h>
+#include "rip.h"
+
 #include <string.h>
 #include <stdio.h>
-#include <erroutines.h>
-
 #include <ctype.h>
-#include <memwrap.h>
-
-#include <numconv.h>
-#include <stubs.h>
-
 #include <sys/socket.h>
 #include <netinet/in.h> 
-
-#include <inet6def.h>
 #include <sys/param.h>
+#include <stdlib.h>
+#include <limits.h>
+#include <errno.h>
+
+/* workaround to fix broken include files with Linux */
+#ifndef ULLONG_MAX
+#define ULLONG_MAX 18446744073709551615ULL
+#endif
+
 
 /**************************************************************************/
 /*+ return the max. length of bits per space
@@ -455,9 +456,7 @@ IP_rang_t2b(ip_range_t *rangptr, char *rangstr, ip_exp_t expf)
     unsigned partlen = dash - rangstr;
 
     /* copy the first IP */
-    if( (err = wr_calloc( (void*) &ips,1, partlen+1)) != UT_OK ) {
-      return err;
-    }
+    ips = (char *)UT_calloc(1, partlen+1);
 
     strncpy(ips, rangstr, partlen);
     
@@ -466,7 +465,7 @@ IP_rang_t2b(ip_range_t *rangptr, char *rangstr, ip_exp_t expf)
 
     /* check later */ /* set error flag: incorrect address format */
 
-    wr_free(ips);
+    UT_free(ips);
 
     if( err != IP_OK ) {
       return err;
@@ -769,10 +768,23 @@ er_ret_t
 IP_addr_f2b_v6(ip_addr_t *addrptr, char *msbstr, char *lsbstr )
 {
   ip_v6word_t high, low;
+  char *endptr;
   
-  if( sscanf(msbstr, "%llu", &high) < 1 ||
-      sscanf(lsbstr, "%llu", &low)  < 1 ) {
-    return IP_INVARG;
+  errno = 0;
+  high = strtoull(msbstr, &endptr, 10);
+  if (((high == 0) || (high == ULLONG_MAX)) && (errno != 0)) {
+      return IP_INVARG;
+  }
+  if (*endptr != '\0') {
+      return IP_INVARG;
+  }
+  errno = 0;
+  low = strtoull(lsbstr, &endptr, 10);
+  if (((low == 0) || (low == ULLONG_MAX)) && (errno != 0)) {
+      return IP_INVARG;
+  }
+  if (*endptr != '\0') {
+      return IP_INVARG;
   }
  
   return IP_addr_v6_mk(addrptr, high, low);
@@ -1109,9 +1121,7 @@ ip_prefix_t *prefptr;
  
  if( ad(begin).words[0] == ad(end).words[0] ) { /* an IP == a /32 (IPv4) */
    prefmask |= 1;
-   if(  wr_calloc( (void **)& prefptr, sizeof(ip_prefix_t), 1) != UT_OK) {
-     die;
-   }
+   prefptr = (ip_prefix_t *)UT_calloc(sizeof(ip_prefix_t), 1);
    prefptr->ip = ad(begin);
    prefptr->bits = 32;
    
@@ -1157,9 +1167,7 @@ ip_prefix_t *prefptr;
   
   if( workbegin.words[0] != workend.words[0] ) {
     prefmask |= blk;
-    if(  wr_malloc( (void **)& prefptr, sizeof(ip_prefix_t)) != UT_OK) {
-      die;
-    }
+    prefptr = (ip_prefix_t *)UT_malloc(sizeof(ip_prefix_t));
     prefptr->ip = workbegin;
     prefptr->bits = slash;
     
@@ -1397,7 +1405,7 @@ IP_smart_conv(char *key,
 	      )
 {
   int free_it;
-  er_ret_t call_err, err=IP_OK;      /* let's be optimistic :-) */
+  er_ret_t err=IP_OK;      /* let's be optimistic :-) */
   ip_prefix_t *querypref;
 
   /* if just checking the syntax (justcheck == 1), 
@@ -1407,10 +1415,7 @@ IP_smart_conv(char *key,
 
   free_it = justcheck;
   
-  if( (call_err = wr_malloc( (void **) &querypref, sizeof(ip_prefix_t))) 
-      != UT_OK) {
-    return call_err;
-  }
+  querypref = (ip_prefix_t *)UT_malloc(sizeof(ip_prefix_t));
   
   if( IP_pref_t2b(querypref, key, expf) == IP_OK ) {
     *keytype = IPK_PREFIX;
@@ -1466,7 +1471,7 @@ IP_smart_conv(char *key,
   }
   
   if( free_it ) {
-    wr_free(querypref);
+    UT_free(querypref);
   }
   
   return err;
