@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 2.25 $
+  $Revision: 2.27 $
 
   mm - MIME Parser module. Functions to parse a mail message part,
   find if it is MIME-encapsulated, dispatch the part to the
@@ -11,7 +11,7 @@
   Design and implementation by: daniele@ripe.net
 
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001                            RIPE NCC
  
   All Rights Reserved
   
@@ -72,6 +72,7 @@
 **************************/
 
 
+#include "rip.h"
 
 /* Standard headers */
 #include <stdio.h>
@@ -84,13 +85,8 @@
 #include <regex.h>
 #include <unistd.h>
 
-
-
-/* This is the local header */
-#include "mm.h"
-
-/* Other RIP headers */
-#include "erroutines.h"
+/* c-client headers */
+#include "misc.h"
 
 
 /* 
@@ -477,7 +473,7 @@ t_MM_type is_supported_MIMEtype (BODY *body)
       tmptype = supported_MIME_types[++i];
     }
 
-  free(mimetype_string);
+  UT_free(mimetype_string);
 
   return(mtypecode);
 
@@ -557,7 +553,7 @@ void parse_text_plain(MAILSTREAM *stream, BODY *body, char *pfx, EP_mail_node *m
       if (debug >= 2) ER_dbg_va (FAC_MM, ASP_MM_GEN, "MAILNODE->FILE: %s",mailnode->file);
       /* The filename of the root node has to be redefined to the processed file */
       /* remove(mailnode->file); */ /* This causes complaints by mail_close() */
-      free(mailnode->file);
+      UT_free(mailnode->file);
       mailnode->file = (char *)UT_malloc(FILENAME_LENGTH);
       sprintf(mailnode->file,"%s%d",EP_outputPrefix,mailnode->nodeID);
       if (debug >= 2) ER_dbg_va (FAC_MM, ASP_MM_GEN, "MAILNODE->FILE: %s",mailnode->file);
@@ -641,7 +637,7 @@ void parse_message_rfc822(MAILSTREAM *stream, BODY *body, char *pfx, EP_mail_nod
   MM_extract_mime(tmpfile, pfx, mailnode, debug);
 
   /* Clean up... */
-  free(content);
+  UT_free(content);
   remove(tmpfile);
 
 }
@@ -734,7 +730,7 @@ void parse_multipart_alternative (MAILSTREAM *stream, BODY *body, char *pfx, EP_
       MM_extract_mime(tmpfile, childpfx, newnode, debug);
 
       /* Clean up... */
-      free(content);
+      UT_free(content);
       remove(tmpfile);
 
       /* Initialize the next node (if it exists) */
@@ -835,7 +831,7 @@ void parse_multipart_signed (MAILSTREAM *stream, BODY *body, char *pfx, EP_mail_
   write_file(newnode->file,content,strlen(content));
 
 
-  free(content);
+  UT_free(content);
 
   /* Signature */
 
@@ -878,7 +874,7 @@ void parse_multipart_signed (MAILSTREAM *stream, BODY *body, char *pfx, EP_mail_
 
   EP_MIMEParse(newnode);
 
-  free(content);
+  UT_free(content);
   remove(tmpfile);
 
 
@@ -940,6 +936,10 @@ Mail_Header_Field *get_mail_hdr_field (MAILSTREAM *stream,
   titlesize = strlen(hdr_title) + 2;
 
   j = 0;
+  /* also initialize tmpline */
+  for(i = 0; i < MAXBUFSIZE; i++){
+    tmpline[i] = '\0';
+  }
 
   /* Get one line at a time, and put the header lines in the Mail Header Field */
 
@@ -974,6 +974,11 @@ Mail_Header_Field *get_mail_hdr_field (MAILSTREAM *stream,
 		}
 	    }
 	  j = 0;	  
+    /* re-initialize tmpline */
+    for(i = 0; i < MAXBUFSIZE; i++){
+      tmpline[i] = '\0';
+    }
+
 	}
       else
 	{
@@ -982,7 +987,7 @@ Mail_Header_Field *get_mail_hdr_field (MAILSTREAM *stream,
 
     }
 
-  free(tmphdr);
+  UT_free(tmphdr);
 
   return (hdr_field);
 
@@ -1139,7 +1144,7 @@ int do_regex_test (const char *pattern, char *string)
   regfree(re);
 
   /* Caution! regfree() does not do this job... */
-  free(re);
+  UT_free(re);
 
   return(match);
 
