@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.8 $
+  $Revision: 1.11 $
 
   Status: NOT REVUED, NOT TESTED
 
@@ -84,6 +84,9 @@ char *NH_convert(nic_handle_t *nh_ptr)
  char *nic_components[4];
  char *nic_handle;
  int nc=0;
+  
+  if(nh_ptr == NULL) return(NULL);
+  
   /* Check for special cases */
   /* Is is and AUTO nic-handle ? */
   if(nh_ptr->nic_id == AUTO_NIC_ID) return(NULL);
@@ -119,7 +122,7 @@ char *NH_convert(nic_handle_t *nh_ptr)
 * Returns:                                                  *
 * >0 - success                                              *
 *  0 - AUTO NIC                                             *
-* -1  - error (not defined and processed yet)               *
+* -1  - error                                               *
 *                                                           *
 ************************************************************/
 int NH_parse(char *nic, nic_handle_t **nh_ptr_ptr)
@@ -129,22 +132,28 @@ int res = 1;
 nic_handle_t *nh_ptr;
 
      if(!(nh_ptr=calloc(1, sizeof(nic_handle_t)))) die;
+     *nh_ptr_ptr=NULL;
      
      ptr=nic;	
 
      /* extract space */
      while(isalpha((int)*ptr))ptr++;
+     /*XXX sanity check - space <=4 characters */
+     if((ptr-nic)>MAX_NH_SPACE_LENGTH) {
+	     UT_free(nh_ptr);
+	     return(-1);
+     }
      if(!(nh_ptr->space=malloc(ptr-nic+1))) die;
      strncpy(nh_ptr->space, nic, ptr-nic); *(nh_ptr->space+(ptr-nic))='\0';
 
-     /* If there are no digits, then this is no nic-hdl */
+     /* If there are no digits, then this is a 'no' nic-hdl */
      /* We reserve NULL_NIC_ID for such pretty identifiers */
      if(*ptr == '\0') {
        nh_ptr->nic_id=NULL_NIC_ID;
        nh_ptr->source=NULL;
      }
      else {
-       /* Check if it is and AUTO nic */
+       /* Check if it is an AUTO nic */
        if (*ptr == '*') {
 	       /* For AUTO nic_id we reserve AUTO_NIC_ID */
 	       nh_ptr->nic_id=AUTO_NIC_ID;
@@ -157,10 +166,24 @@ nic_handle_t *nh_ptr;
 	 /* Check if there were any digits at all */
 	 if(ptr == nic) nh_ptr->nic_id=NULL_NIC_ID;
        }
+       /*XXX sanity check - if the ID does not exeed NH_MAX_ID */
+       if(nh_ptr->nic_id > MAX_NIC_ID) {
+	       if(nh_ptr) {
+                UT_free(nh_ptr->source);UT_free(nh_ptr);
+               }
+	       return(-1);
+       }
        /* check if there is any suffix */
        if (*ptr == '\0') nh_ptr->source=NULL;
        /* Copy suffix into source */
        else {
+	 /*XXX sanity check - suffix does not exceed the length */
+	 if(strlen(ptr)>MAX_NH_SOURCE_LENGTH) {
+		 if(nh_ptr){
+                   UT_free(nh_ptr->source);UT_free(nh_ptr);
+                  }
+		 return(-1);
+	 }
 	 if(!(nh_ptr->source=malloc(strlen(ptr)+1))) die;
 	 strcpy(nh_ptr->source, ptr);
        }
@@ -187,9 +210,14 @@ int NH_check(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection)
 {
 range_t range;
 long range_id;
-long nic_id=nh_ptr->nic_id;
+long nic_id;
 
 
+  /* this can happen if nic handle is incorrect, NH_parse will null the structure */
+  if( nh_ptr == NULL) return(0);
+
+  nic_id=nh_ptr->nic_id;
+
   range.space=nh_ptr->space;
   if(nh_ptr->source)range.source=nh_ptr->source; else range.source="";
   
@@ -237,9 +265,13 @@ int NH_free(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection, int commit_no
 range_t range;
 long range_id;
 int old_start;
-long nic_id=nh_ptr->nic_id;
+long nic_id;
 
 
+  if(nh_ptr == NULL) return(0);
+
+  nic_id=nh_ptr->nic_id;
+  
   range.space=nh_ptr->space;
   if(nh_ptr->source)range.source=nh_ptr->source; else range.source="";
   
@@ -287,7 +319,8 @@ long nic_id=nh_ptr->nic_id;
 *                                                           *
 * Returns:                                                  *
 * 1 - success                                               *
-* 0  - nic_id already exists or space is fully occupied     *
+* 0  - wrong nic handle, nic_id already exists or           * 
+*      space is fully occupied                              *
 * -1 - error (f.e. more than one object with the same PK)   *
 *                                                           *
 ************************************************************/
@@ -295,10 +328,12 @@ int NH_register(nic_handle_t *nh_ptr, SQ_connection_t *sql_connection, int commi
 {
 range_t range;
 long range_id;
-long nic_id=nh_ptr->nic_id;
+long nic_id;
 
 
+  if(nh_ptr == NULL) return(0);
 
+  nic_id=nh_ptr->nic_id;
 
  /* Yiu should check for nh first for AUTO nic-handles */
   if (nic_id == AUTO_NIC_ID) { return(0); };
@@ -347,9 +382,9 @@ long nic_id=nh_ptr->nic_id;
 void free_nh(nic_handle_t *nh_ptr)
 {
  if(nh_ptr){
-   if(nh_ptr->space)free(nh_ptr->space);
+   if(nh_ptr->space)UT_free(nh_ptr->space);
    if(nh_ptr->source)free(nh_ptr->source);
-   free(nh_ptr);
+   UT_free(nh_ptr);
  }
 }
 
@@ -423,17 +458,17 @@ int sql_err;
    sql_str = SQ_get_column_string(sql_result, sql_row, RANGE_ID);
    if (sql_str != NULL) {
      range_id = atol(sql_str);
-     free(sql_str);
+     UT_free(sql_str);
    }
    sql_str = SQ_get_column_string(sql_result, sql_row, RANGE_START);
    if (sql_str != NULL) {
      prange->start = atoi(sql_str);
-     free(sql_str);
+     UT_free(sql_str);
    }
    sql_str = SQ_get_column_string(sql_result, sql_row, RANGE_END);
    if (sql_str != NULL) {
      prange->end = atoi(sql_str);
-     free(sql_str);
+     UT_free(sql_str);
    }
 
 /* We must process all the rows of the result */
@@ -639,6 +674,7 @@ static long create_range(range_t *p_range, SQ_connection_t *sql_connection, int
 {
 GString *query;
 int sql_err, num;
+long range_id;
 
  /* Allocate memory */
  if ((query = g_string_sized_new(STR_L)) == NULL){ 
@@ -646,14 +682,21 @@ int sql_err, num;
   return(-1); 
  }
  
+ /* get the next range_id */
+ /* XXX we cannot use autoincrement with MyISAM tables */
+ /* XXX because they keep the max inserted id even if  */
+ /* XXX it was deleted later, thus causing gaps we don't want */
+ 
+ range_id=SQ_get_max_id(sql_connection, "range_id", "nic_hdl") +1;
+ 
  if(commit_now)
   g_string_sprintf(query, "INSERT nic_hdl "
-                          "SET thread_id=0, space='%s', source='%s', range_start=%ld, range_end=%ld ",
-                           p_range->space, p_range->source, p_range->start, p_range->end);
+                          "SET thread_id=0,  range_id=%ld, space='%s', source='%s', range_start=%ld, range_end=%ld ",
+                           range_id, p_range->space, p_range->source, p_range->start, p_range->end);
  else	 
   g_string_sprintf(query, "INSERT nic_hdl "
-                          "SET thread_id=%d, space='%s', source='%s', range_start=%ld, range_end=%ld ",
-                           NH_INSERT, p_range->space, p_range->source, p_range->start, p_range->end);
+                          "SET thread_id=%d, range_id=%ld, space='%s', source='%s', range_start=%ld, range_end=%ld ",
+                           NH_INSERT, range_id, p_range->space, p_range->source, p_range->start, p_range->end);
 
 /* fprintf(stderr, "create_range[%s]\n", query->str); */
  sql_err=SQ_execute_query(sql_connection, query->str, (SQ_result_set_t **)NULL);
@@ -666,7 +709,7 @@ int sql_err, num;
    num = SQ_get_affected_rows(sql_connection); 
    /* this should not happen */
    if(num==0) die;
- return(SQ_get_insert_id(sql_connection));
+ return(range_id);
 }
 
 
