@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.15 $
+  $Revision: 1.16 $
 
   Radix payload (rp) - user level functions for storing data in radix trees
 
@@ -12,7 +12,7 @@
   Design and implementation by: Marek Bukowy
   
   ******************/ /******************
-  Copyright (c) 1999                              RIPE NCC
+  Copyright (c) 1999,2000,2001                    RIPE NCC
  
   All Rights Reserved
   
@@ -32,8 +32,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
 
-
-#include <rp.h>
+#include "rip.h"
 
 static
 void
@@ -364,24 +363,18 @@ static
 er_ret_t
 rp_asc_append_datref(rx_datref_t *refptr, GList **finallist)
 {
-  er_ret_t err;
   rx_datcpy_t *datcpy;
   void *dataptr;
 
     /* OK, so we ACCEPT this result. Copy it.*/
 
-    if( (err=wr_calloc( (void **)& datcpy, 1, sizeof(rx_datcpy_t))) != UT_OK) {
-      return err; /*    die;*/
-    }
+    datcpy = (rx_datcpy_t *)UT_calloc(1, sizeof(rx_datcpy_t));
     
     datcpy->leafcpy = *(refptr->leafptr);
     
     /* copy the immediate data too. Set the ptr.*/
     
-    if( (err=wr_calloc( (void **) & dataptr, 1, refptr->leafptr->data_len)) 
-        != UT_OK) {
-      return err; /*    die;*/
-    }
+    dataptr = UT_calloc(1, refptr->leafptr->data_len);
     memcpy(dataptr, refptr->leafptr->data_ptr, refptr->leafptr->data_len);
     
     datcpy->leafcpy.data_ptr = dataptr;
@@ -551,12 +544,14 @@ RP_asc_search (
   IP_smart_range(key, &testrang, IP_EXPN, &key_type);
   
   /* find the tree */
-  if( NOERR(err) ) {
+  /* I took out the surrounding "if" because it is always taken when 
+     we get to this point, and it causes compiler warnings otherwise - shane */
+  /*if( NOERR(err) ) {*/
     spc_id = IP_pref_b2_space( g_list_first(preflist)->data );
     if( ! NOERR(err = RP_tree_get( &mytree, reg_id, spc_id, attr ))) {
       return err;
     }
-  }
+  /*}*/
   /* the point of no return: now we lock the tree. From here, even if errors
      occur, we still go through all procedure to unlock the tree at the end */
   
