@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.18 $
+  $Revision: 1.19 $
 
   Socket module - routines facilitating calls to socket library.
 
@@ -14,7 +14,7 @@
         joao   (22/06/1999) Modified socket creation and accepts.
 	marek  (December 2000) Added connection function w/timeout.
   ******************/ /******************
-  Copyright (c) 1999, 2000                           RIPE NCC
+  Copyright (c) 1999, 2000, 2001                     RIPE NCC
  
   All Rights Reserved
   
@@ -34,15 +34,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
 
-#include "sk.h"
-#include "constants.h"
-#include "stubs.h"
-
-#include "memwrap.h"
-
-/*+ String sizes +*/
-#define STR_S   63
-#define STR_XXL 16383
+#include "rip.h"
 
 /* SK_atoport() */
 /*++++++++++++++++++++++++++++++++++++++
@@ -628,7 +620,7 @@ char *SK_getpeername(int  sockfd)
  
   if (getpeername(sockfd, (struct sockaddr *)&addr_in, &namelen) == 0) {
 
-    dieif( wr_malloc((void **)&hostaddress, INET_ADDRSTRLEN) != UT_OK); 
+    hostaddress = (char *)UT_malloc(INET_ADDRSTRLEN);
     inet_ntop(AF_INET, &(addr_in.sin_addr),  hostaddress, INET_ADDRSTRLEN);
   }
   else {
