@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.37 $
+  $Revision: 1.39 $
 
   SQL module (sq) - this is a MySQL implementation of the SQL module.
 
@@ -11,7 +11,7 @@
                         marek@ripe.net
   OSs Tested          : Solaris 7 / sun4u / sparc
   ******************/ /******************
-  Copyright (c) 1999                              RIPE NCC
+  Copyright (c) 1999, 2000, 2001                  RIPE NCC
  
   All Rights Reserved
   
@@ -30,6 +30,9 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
+
+#include "rip.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -38,18 +41,7 @@
 #include <sys/types.h>
 #include <limits.h>
 #include <errno.h>
-
-#include "mysql_driver.h"
-#include "constants.h"
-#include "memwrap.h"
-#include "timediff.h"
-
-/*+ String sizes +*/
-#define STR_S   63
-#define STR_M   255
-#define STR_L   1023
-#define STR_XL  4095
-#define STR_XXL 16383
+#include <glib.h>
 
 /* 
 Description:
@@ -218,7 +210,7 @@ int SQ_execute_query(SQ_connection_t *sql_connection,
   ut_timer_t start_time, stop_time; 
   
   UT_timeget(&start_time);
-  
+
   err = mysql_query(sql_connection, query);
 
   /* log the time and result of the query */
@@ -324,18 +316,21 @@ int SQ_get_column_count(SQ_result_set_t *result) {
 int SQ_get_table_size(SQ_connection_t *sql_connection,
 		     char *table) {  
   int count;
-  char sql_command[128];
+  GString *sql_command;
   SQ_result_set_t *result;
   SQ_row_t *row;
   char *countstr;
   
-  sprintf(sql_command, "SELECT COUNT(*) FROM %s", table);
-  dieif(SQ_execute_query(sql_connection, sql_command, &result) == -1 );
+  sql_command = g_string_new("");
+  g_string_sprintf(sql_command, "SELECT COUNT(*) FROM %s", table);
+  dieif(SQ_execute_query(sql_connection, sql_command->str, &result) == -1 );
+  g_string_free(sql_command, TRUE);
+
   row = SQ_row_next(result);
   
   countstr = SQ_get_column_string(result, row, 0);
   sscanf(countstr, "%d", &count);	
-  wr_free(countstr);
+  UT_free(countstr);
   
   SQ_free_result(result);
 	
@@ -404,17 +399,13 @@ char *SQ_get_column_label(SQ_result_set_t *result, unsigned int column) {
 
   field = mysql_fetch_field_direct(result, column);
 
-  /*str = (char *)calloc(1, strlen(field.name)+1);*/
-  dieif( wr_malloc((void **)&str, strlen(field.name)+1) != UT_OK);  
-  strcpy(str, field.name);
+  str = UT_strdup(field.name);
 #else
   MYSQL_FIELD *field;
 
   field = mysql_fetch_field_direct(result, column);
 
-  /*str = (char *)calloc(1, strlen(field->name)+1);*/
-  dieif( wr_malloc((void **)&str, strlen(field->name)+1) != UT_OK); 
-  strcpy(str, field->name);
+  str = UT_strdup(field->name);
 #endif
 
 /*
@@ -520,12 +511,9 @@ char *SQ_get_column_string(SQ_result_set_t *result, SQ_row_t *current_row, unsig
   unsigned length = mysql_fetch_lengths(result)[column];
   
   if (current_row != NULL && current_row[column] != NULL) {
-    /*str = (char *)malloc(length + 1);*/
-    dieif( wr_malloc((void **)&str, length + 1) != UT_OK);  
-    if (str != NULL) {
-      memcpy(str, current_row[column], length );
-      str[length] = '\0';
-    }
+    str = (char *)UT_malloc(length + 1);
+    memcpy(str, current_row[column], length );
+    str[length] = '\0';
   }
 
   return str;
@@ -566,33 +554,30 @@ char *SQ_get_column_string_nocopy(SQ_result_set_t *result,
   ++++++++++++++++++++++++++++++++++++++*/
 char *SQ_get_column_strings(SQ_result_set_t *result, unsigned int column) {
   MYSQL_ROW row;
-  char str_buffer[STR_XXL];
-  char str_buffer_tmp[STR_L];
+  GString *buf;
   char *str;
 
-  strcpy(str_buffer, "");
+  /* allocate a buffer for building the result in */
+  buf = g_string_sized_new(STR_XXL);
 
+  /* add each row of the result as a line to our result buffer */
   while ((row = mysql_fetch_row(result)) != NULL) {
     if (row[column] != NULL) {
-      sprintf(str_buffer_tmp, "%s\n", row[column]);
-    }
-    strcat(str_buffer, str_buffer_tmp);
-
-    if (strlen(str_buffer) >= (STR_XXL - STR_XL) ) {
-      strcat(str_buffer, "And some more stuff...\n");
-      break;
+      g_string_append(buf, row[column]);
+      g_string_append_c(buf, '\n');
     }
   }
 
-  if (strcmp(str_buffer, "") != 0) {
-    /*str = (char *)calloc(1, strlen(str_buffer)+1);*/
-    dieif( wr_malloc((void **)&str, strlen(str_buffer)+1) != UT_OK);  
-    strcpy(str, str_buffer);
-  }
-  else {
+  /* if something found, copy to a string for return */
+  if (buf->len > 0) {
+    str = UT_strdup(buf->str);
+  } else {
     str = NULL;
   }
 
+  /* free temporary memory */
+  g_string_free(buf, TRUE);
+
   return str;
 
 } /* SQ_get_column_strings() */
@@ -674,7 +659,6 @@ char *SQ_result_to_string(SQ_result_set_t *result) {
   char str_buffer[STR_XXL];
   char str_buffer_tmp[STR_L];
   char border[STR_L];
-  char *str;
 
   char *label;
 
@@ -739,11 +723,7 @@ char *SQ_result_to_string(SQ_result_set_t *result) {
 
   strcat(str_buffer, border);
   
-  /* str = (char *)calloc(1, strlen(str_buffer)+1);*/
-  dieif( wr_malloc((void **)&str, strlen(str_buffer)+1) != UT_OK);  
-  strcpy(str, str_buffer);
-
-  return str;
+  return UT_strdup(str_buffer);
 
 } /* SQ_result_to_string() */
 
@@ -836,51 +816,45 @@ int SQ_num_rows(SQ_result_set_t *result) {
 
   ++++++++++++++++++++++++++++++++++++++*/
 char *SQ_info_to_string(SQ_connection_t *sql_connection) {
-  char str_buffer[STR_XXL];
-  char str_buffer_tmp[STR_L];
-  char *str;
+  GString *buf;
   char *str_tmp;
+  char *result;
 
-  strcpy(str_buffer, "");
+  buf = g_string_sized_new(STR_XXL);
 
   /* Makes the server dump debug information to the log. */
-  sprintf(str_buffer_tmp, "mysql_dump_debug_info()=%d\n", mysql_dump_debug_info(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_dump_debug_info()=%d\n", 
+                    mysql_dump_debug_info(sql_connection));
 
   /* Returns the error number from the last MySQL function. */
-  sprintf(str_buffer_tmp, "mysql_errno()=%d\n", mysql_errno(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_errno()=%d\n", mysql_errno(sql_connection));
 
   /* Returns the error message from the last MySQL function. */
-  sprintf(str_buffer_tmp, "mysql_error()=%s\n", mysql_error(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_error()=%s\n", mysql_error(sql_connection));
 
   /* Returns client version information. */
-  sprintf(str_buffer_tmp, "mysql_get_client_info()=%s\n", mysql_get_client_info() );
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_get_client_info()=%s\n", 
+                    mysql_get_client_info() );
 
   /* Returns a string describing the connection. */
-  sprintf(str_buffer_tmp, "mysql_get_host_info()=%s\n", mysql_get_host_info(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_get_host_info()=%s\n",
+                    mysql_get_host_info(sql_connection));
 
   /* Returns the protocol version used by the connection. */
-  sprintf(str_buffer_tmp, "mysql_get_proto_info()=%d\n", mysql_get_proto_info(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_get_proto_info()=%d\n", 
+                    mysql_get_proto_info(sql_connection));
 
   /* Returns the server version number. */
-  sprintf(str_buffer_tmp, "mysql_get_server_info()=%s\n", mysql_get_server_info(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_get_server_info()=%s\n",
+                    mysql_get_server_info(sql_connection));
 
   /* Information about the most recently executed query. */
-  /* XXX Check for NULL */
   str_tmp = mysql_info(sql_connection);
   if (str_tmp != NULL) {
-    sprintf(str_buffer_tmp, "mysql_info()=%s\n", str_tmp);
+    g_string_sprintfa(buf, "mysql_info()=\"%s\"\n", str_tmp);
+  } else {
+    g_string_append(buf, "mysql_info()=NULL\n");
   }
-  else {
-    sprintf(str_buffer_tmp, "mysql_info()=%s\n", "NulL");
-  }
-  strcat(str_buffer, str_buffer_tmp);
 
 
   /* Returns a list of the current server threads. 
@@ -894,23 +868,20 @@ char *SQ_info_to_string(SQ_connection_t *sql_connection) {
   */
 
   /* Checks if the connection to the server is working. */
-  sprintf(str_buffer_tmp, "mysql_ping()=%d\n", mysql_ping(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_ping()=%d\n", mysql_ping(sql_connection));
 
   /* Returns the server status as a string. */
-  sprintf(str_buffer_tmp, "mysql_stat()=%s\n", mysql_stat(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_stat()=%s\n", mysql_stat(sql_connection));
 
   /* Returns the current thread id. */
-  sprintf(str_buffer_tmp, "mysql_thread_id()=%ld\n", mysql_thread_id(sql_connection));
-  strcat(str_buffer, str_buffer_tmp);
+  g_string_sprintfa(buf, "mysql_thread_id()=%ld\n",
+                    mysql_thread_id(sql_connection));
 
 
-  /*str = (char *)calloc(1, strlen(str_buffer)+1);*/
-  dieif( wr_malloc((void **)&str, strlen(str_buffer)+1) != UT_OK);  
-  strcpy(str, str_buffer);
-
-  return str;
+  /* copy our string and return the copy */
+  result = UT_strdup(buf->str);
+  g_string_free(buf, TRUE);
+  return result;
 
 } /* SQ_info_to_string() */
 
@@ -1082,7 +1053,7 @@ int SQ_ping(SQ_connection_t *sql_connection)
 
 long sq_get_minmax_id(SQ_connection_t *sql_connection, char *id_name, char *table, int max)
 {
-char query[STR_M];
+GString *query;
 SQ_result_set_t *sql_result;
 SQ_row_t *sql_row;
 char *sql_str;
@@ -1090,14 +1061,17 @@ long id;
 char *minmax;
 int sql_err;
 
+query = g_string_sized_new(STR_M);
+
 if(max==1)minmax="max"; else minmax="min";
 
- sprintf(query, "SELECT %s(%s) FROM %s ", minmax, id_name, table);
+ g_string_sprintf(query, "SELECT %s(%s) FROM %s ", minmax, id_name, table);
 
- sql_err = SQ_execute_query(sql_connection, query, &sql_result);
+ sql_err = SQ_execute_query(sql_connection, query->str, &sql_result);
  
  if(sql_err) {
-    ER_perror(FAC_SQ, SQ_CNCT, "%s[%s]\n", SQ_error(sql_connection), query);
+    ER_perror(FAC_SQ, SQ_CNCT, "%s[%s]\n", SQ_error(sql_connection), 
+              query->str);
     die;
  }
         
@@ -1108,7 +1082,7 @@ if(max==1)minmax="max"; else minmax="min";
      /* We must process all the rows of the result,*/
      /* otherwise we'll have them as part of the next qry */
 	while ( (sql_row = SQ_row_next(sql_result)) != NULL) {
-	  ER_perror(FAC_SQ, SQ_CNCT, "duplicate max [%s]\n", query);
+	  ER_perror(FAC_SQ, SQ_CNCT, "duplicate max [%s]\n", query->str);
 	  die;
 	}
  }
@@ -1118,10 +1092,13 @@ if(max==1)minmax="max"; else minmax="min";
  
  if(sql_str) {
   id = atol(sql_str);
-  free(sql_str);
+  UT_free(sql_str);
  }
  /* table is empty, max_id=min_id=0 */
  else id=0;
+
+ /* free temporary space used for query */
+ g_string_free(query, TRUE);
  
  return(id);
  
