@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.26 $
+  $Revision: 1.29 $
 
   rollback(), commit(), delete() - rollback, commit update transaction, delete an object
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (17/01/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001                         RIPE NCC
  
   All Rights Reserved
   
@@ -30,11 +30,9 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/
-#include "ud.h"
-#include "ud_int.h"
+
+#include "rip.h"
 #include "ud_comrol.h"
-#include "ud_tr.h"
-#include "rp.h"
 
 
 /************************************************************
@@ -267,8 +265,8 @@ int sql_err;
                  break;
       default:
 		 ER_perror(FAC_UD, UD_BUG, "not valid class type\n");
+                 attr_type=A_END;
                  die;
-                 break;           
      }
      g_string_sprintf(query, DF_get_update_query(attr_type), DF_get_class_sql_table(tr->class_type), 0, (char *)tr->save, tr->object_id);
      sql_err = SQ_execute_query(tr->sql_connection, query->str, (SQ_result_set_t **)NULL);
@@ -421,14 +419,16 @@ char *sql_str;
         /* Calculate number of references */
         sql_str= get_field_str(tr->sql_connection, "COUNT(*)", t_ipn[i], "pe_ro_id", sobject_id, NULL);
         if(sql_str) {
-         num_rec = atol(sql_str);  free(sql_str);
+         num_rec = atol(sql_str);  UT_free(sql_str);
          ref_id=tr->object_id;
          /* Check if it is a self reference (for role objects) */
          if(num_rec==1) {
           sql_str= get_field_str(tr->sql_connection, "object_id", t_ipn[i], "pe_ro_id", sobject_id, NULL);
           if(sql_str) {
-           ref_id = atol(sql_str);  free(sql_str);
+           ref_id = atol(sql_str);  UT_free(sql_str);
           } else {
+	   /* this is not possible unless it is an sql error */
+	   /*XXX probably we need to die */	  
            tr->succeeded=0; tr->error |= ERROR_U_DBS; break;
           }
          }
@@ -457,7 +457,7 @@ char *sql_str;
         
         sql_str= get_qresult_str(tr->sql_connection, query->str);
         if(sql_str) {
-         num_rec = atol(sql_str);  free(sql_str);
+         num_rec = atol(sql_str);  UT_free(sql_str);
          /* If there are references (no self reference is possible in this case) we cannot delete */
          if(num_rec>0) {
            g_string_sprintfa(tr->error_script,"E[%d][%ld]:ref integrity: %s\n" ,ERROR_U_OBJ, num_rec, t_ipn[i]);
@@ -480,13 +480,13 @@ char *sql_str;
        /* Calculate number of references */
         sql_str= get_field_str(tr->sql_connection, "COUNT(*)", t_imt[i], "mnt_id", sobject_id, NULL);
         if(sql_str) {
-         num_rec = atol(sql_str);  free(sql_str);
+         num_rec = atol(sql_str);  UT_free(sql_str);
          ref_id=tr->object_id;
          /* Check if it is a self reference  */
          if(num_rec==1) { 
             sql_str= get_field_str(tr->sql_connection, "object_id", t_imt[i], "mnt_id", sobject_id, NULL);
             if(sql_str) {
-              ref_id = atol(sql_str);  free(sql_str);
+              ref_id = atol(sql_str);  UT_free(sql_str);
             } else {
               tr->succeeded=0; tr->error |= ERROR_U_DBS; break;
             } 
@@ -508,7 +508,7 @@ char *sql_str;
         /* Calculate number of references */
         sql_str= get_field_str(tr->sql_connection, "COUNT(*)", "member_of", "set_id", sobject_id, NULL);
         if(sql_str) {
-         num_rec = atol(sql_str);  free(sql_str);
+         num_rec = atol(sql_str);  UT_free(sql_str);
          /* XXX though set may contain other sets as memebers, */
          /* there is no member-of attribute in these objects. */
          /* So no self-reference is possible */
