@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.53 $
+  $Revision: 1.55 $
 
   Functions to process data stream( file, network socket, etc.)
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (17/01/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001                         RIPE NCC
  
   All Rights Reserved
   
@@ -30,6 +30,9 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/
+
+#include "rip.h"
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
@@ -38,12 +41,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
-#include "constants.h"
-#include "query_command.h"
-#include "ud.h"
-#include "ud_int.h"
-#include "ud_tr.h"
-#include "timediff.h"
+
  
 typedef enum _Line_Type_t {
  LINE_ATTRIBUTE,
@@ -173,13 +171,14 @@ static GSList *ud_split_attribute(GSList *attr_list, Attribute_t *attr)
       if (attr_split) the_list = g_slist_append(the_list, attr_split);
     }
   }
-  free(value);
+  UT_free(value);
   attribute_free(attr, NULL);
 
  return(the_list);
 }
 
 /* XXX */
+/* commented out because it is unused - shane
 static void each_attribute_print(void *element_data, void *tr_ptr)
 {
 
@@ -188,13 +187,16 @@ Attribute_t *attr = (Attribute_t *)element_data;
  fprintf(stderr, "[%d|%s]\n", attr->type, attr->value);
 
 }
+*/
 
 /* XXX */
+/* commented out because it is unused - shane
 static void print_object(Object_t *obj)
 {
   g_slist_foreach(obj->attributes, each_attribute_print, NULL);	
   fprintf(stderr, ">>>>>\n%s\n", obj->object->str);
 }
+*/
 
 
 /******************************************************************
@@ -628,7 +630,8 @@ int ta_upd_nhr;
           /* check if we are replacing a dummy object */
 	  dummy=isdummy(tr);
           /* If we are replacing dummy with a real object update NHR */
-          if(dummy==1) tr->action = (ta_upd_nhr | TA_UPD_DUMMY);
+/*          if(dummy==1) tr->action = (ta_upd_nhr | TA_UPD_DUMMY); */
+          if(dummy==1) tr->action = TA_UPD_DUMMY;
 /*        fprintf(stderr,"UPDATE next(dummy)\n"); */
           object_process(tr); /* create a new one*/
 /*          result=report_transaction(tr, log_ptr, object_name, "NRTM:ADD:While creating new"); */
@@ -673,7 +676,8 @@ int ta_upd_nhr;
         tr->action=TA_UPDATE;
         dummy=isdummy(tr);
         /* If we are replacing dummy with a real object update NHR */
-        if(dummy==1) tr->action = ( ta_upd_nhr| TA_UPD_DUMMY);
+/*        if(dummy==1) tr->action = ( ta_upd_nhr| TA_UPD_DUMMY);*/
+         if(dummy==1) tr->action = TA_UPD_DUMMY;
         object_process(tr);
         /* For serials this is CREATE operation. Increase sequence to have it correct in serals */
         if(dummy==1) { tr->action=TA_CREATE; tr->sequence_id++; }
@@ -791,6 +795,7 @@ char *reason;
       if(tr->object_id!=0) { /* trying to create, but object exists */
         tr->succeeded=0; tr->error|=ERROR_U_COP;
 	reason="U:ADD:object already exists";
+        g_string_sprintfa(tr->error_script,"E[%d]:NEW requested but object already exists\n" ,ERROR_U_COP);
         UD_ack(tr); /* Send a NACK */
       } else {
        /* Action: create the object and update NHR */
@@ -803,13 +808,15 @@ char *reason;
       if(tr->object_id==0) { /* trying to update non-existing object*/
         tr->succeeded=0; tr->error|=ERROR_U_COP;
 	reason="U:UPD:non-existing object";
+        g_string_sprintfa(tr->error_script,"E[%d]:UPD requested but no existing object found\n" ,ERROR_U_COP);
         UD_ack(tr); /* Send a NACK */
       } else {
         tr->action=TA_UPDATE;
 	reason="U:UPD";
         dummy=isdummy(tr);
         /* If we are replacing dummy with a real object update NHR */
-        if(dummy==1) tr->action = (ta_upd_nhr | TA_UPD_DUMMY);
+/*        if(dummy==1) tr->action = (ta_upd_nhr | TA_UPD_DUMMY); */
+        if(dummy==1) tr->action = TA_UPD_DUMMY;
         object_process(tr);
       }
       break;
@@ -818,6 +825,7 @@ char *reason;
       if(tr->object_id==0) { /* trying t delete non-existing object*/
         tr->succeeded=0; tr->error|=ERROR_U_COP;
 	reason="U:DEL:non-existing object";
+        g_string_sprintfa(tr->error_script,"E[%d]:DEL requested but no existing object found\n" ,ERROR_U_COP);
 	UD_ack(tr);
       } else {
         tr->action=(TA_DELETE | ta_upd_nhr);
@@ -842,6 +850,7 @@ char *reason;
       else {
         tr->succeeded=0; 
         tr->error|=ERROR_U_BADOP;
+        g_string_sprintfa(tr->error_script,"E[%d]:Unknown operation requested\n" ,ERROR_U_BADOP);
 	reason="U:bad operation";
         UD_ack(tr); /* Send a NACK */ 
       }
@@ -991,7 +1000,7 @@ int UD_process_stream(UD_stream_t *ud_stream)
   Log_t *log_ptr= &(ud_stream->log);
   ut_timer_t stime, ftime, sotime;
   float obj_second1, obj_second10, timediff;
-  int result;
+  int result=0;
   int operation=0;
   int interrupt=0;
   int do_update;
