@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.5 $
+  $Revision: 1.6 $
 
   Functions to keep records for crash recovery
 
@@ -11,7 +11,7 @@
   Modification History:
         andrei (11/08/2000) Created.
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001                         RIPE NCC
  
   All Rights Reserved
   
@@ -31,8 +31,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/
 
-#include "ud_tr.h"
-#include "ud.h"
+#include "rip.h"
 
 /*************************************************************
 
