@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.10 $
+  $Revision: 1.11 $
 
   UP external syntax checks
 
@@ -65,6 +65,7 @@ extern int tracing;
 extern char * fingerprint;
 extern char * keyowner;
 
+extern char * allocmnt;
 
 
 /* obtains a list of dates in the given 
@@ -705,18 +706,105 @@ int up_check_an_inetnum_attr(const char * arg){
 }
 
 
+/* Prepares a list of mnt-by attributes */
+GSList * up_get_mntby_list(GSList * attribute_list){
 
-/* void up_check_inetnum_attr 
-   checks the syntax of 'inetnum' attributes 
-   (this is required to reject inetnums in the form of 
-   "inetnum: 23.23.23.23". RPSL parser unfortunately
-   passes them although we define them as a range of ipv4 addreses.) */
+  GSList * to_be_returned = NULL;
+  GSList * next;
+
+  for(next = attribute_list; next != NULL ; next = g_slist_next(next) ){
+    
+    if(strcmp((char *)(((attribute_struct *)(next->data))->type), "mnt-by") == 0){
+      to_be_returned = g_slist_append(to_be_returned, ((attribute_struct *)(next->data))->content);
+    }
+  }
+
+  return to_be_returned;
+  
+}
+
+
+
+
+
+/* Performs a check on status attribute. It can be
+   ALLOCATED PI or ALLOCATED PA only if the maintainers in the
+   mnt-by attribute contain at least one of the names mentioned in
+   ALLOCMNT config variable. 
+*/
+int up_check_a_status_attr(const char * arg, GSList * mnt_by_list){
+
+  GSList * next;
+  int result;
+  char * status, * mnt_by_attrib;
+  char ** allocmnt_list;
+  int i;
+
+  status = strdup(arg);
+  g_strdown(status);
+ 
+  /* construct a list of mntners that are in allocmnt */
+  allocmnt_list = g_strsplit(allocmnt, " ", 0); /* delimited by " " */
+   
+  if(strstr(status, "allocated") != NULL){ 
+
+    result = 1; /* initialize */
+    
+    for( next = mnt_by_list; next != NULL ; next = g_slist_next(next) ){
+
+      mnt_by_attrib = strdup((char *)((attribute_struct *)(next->data)));
+      g_strstrip(mnt_by_attrib);
+      for(i=0; allocmnt_list[i] != NULL; i++){/* loop thru the list of allocmnt maintainers */
+        if((strlen(allocmnt_list[i]) != 0) && strcasecmp(mnt_by_attrib, allocmnt_list[i]) == 0){
+          result = 0; 
+        }
+      }  
+      free(mnt_by_attrib);
+
+    }
+    
+    free(status);
+    return result;
+ 
+  }else{  /* the status attribute  */
+  
+    free(status);
+    return 0; /* so there is no problem */
+
+  }
+
+  g_strfreev(allocmnt_list);
+ 
+  free(status); 
+  return 0;
+
+}
+
+
+
+
+
+
+/* void up_check_inetnum_attr checks the syntax of 'inetnum' 
+   attributes (this is required to reject inetnums in the 
+   form of "inetnum: 23.23.23.23". RPSL parser unfortunately
+   passes them although we define them as a range of ipv4 addreses.) 
+
+   Also, we check for status attribute here: The status attribute can be
+   ALLOCATED PI or ALLOCATED PA only if the maintainers in the
+   mnt-by attribute contain at least one of the names mentioned in
+   ALLOCMNT config variable. 
+*/
 void up_check_inetnum_attr(Object * obj, char * obj_text, GSList * attribute_list, external_syntax_struct * result){
 
   int res;
   char * temp;
   GSList * next;
+  GSList * mnt_by_list = NULL;
 
+  /* Gather a list of mnt-by attributes */
+  mnt_by_list = up_get_mntby_list(attribute_list);
+  
 
   /* loop in the attribute_list, find the 'inetnum' attribs, and check their syntax */
   for( next = attribute_list; next != NULL ; next = g_slist_next(next) ){
@@ -746,6 +834,38 @@ void up_check_inetnum_attr(Object * obj, char * obj_text, GSList * attribute_lis
         }
       }
     }
+
+    /* is this a status attribute? */
+    if(strcmp((char *)(((attribute_struct *)(next->data))->type), "status") == 0){
+      res = up_check_a_status_attr((char *)(((attribute_struct *)(next->data))->content), mnt_by_list);
+      if(res != 0){/* there was a problem */
+        /* so, add the error string to result's error string */
+        if(result->error_str == NULL){
+          result->error_str = (char *)UT_malloc(strlen("***Error: Status ALLOCATED can be set only by the following mntner(s):\n")
+                                                +strlen("***Error:    ") + strlen(allocmnt) + 2);
+          sprintf(result->error_str, "%s%s%s", "***Error: Status ALLOCATED can be set only by the following mntner(s):\n",
+                                               "***Error:    ", allocmnt);
+        }else{
+          temp = (char *)malloc(strlen(result->error_str) 
+                  + strlen("***Error: Status ALLOCATED can be set only by the following mntner(s):\n") 
+                  + strlen("***Error:    ") + strlen(allocmnt) + 2);
+          sprintf(temp, "%s\n%s%s%s", result->error_str, 
+                  "***Error: Status ALLOCATED can be set only by the following mntner(s):\n",
+                  "***Error:    ", allocmnt);
+          free(result->error_str);
+          result->error_str = temp;
+        }
+        /* and here we have to change the result code of "result" here ... */
+        switch(result->result){
+          case UP_EXTSYN_OK:       result->result = UP_EXTSYN_ERR; break;
+          case UP_EXTSYN_ERR:      result->result = UP_EXTSYN_ERR; break;
+          case UP_EXTSYN_WARN:     result->result = UP_EXTSYN_ERR_WARN; break;
+          case UP_EXTSYN_ERR_WARN: result->result = UP_EXTSYN_ERR_WARN; break;
+          default: ;
+        }
+ 
+      }
+    }
   }
 }
 
@@ -923,6 +1043,7 @@ external_syntax_struct * UP_check_external_syntax(Object * arg, char * obj_text)
   up_check_auth_attr   (arg, obj_text, attribute_list, result);  
   up_check_inetnum_attr(arg, obj_text, attribute_list, result);
   
+  
   up_reconstruct_object(attribute_list, result);
 
   if(tracing){
