@@ -22,7 +22,9 @@ char * UP_put_assigned_NIC(char * arg, const char * assigned_NIC);
 
 char * UP_get_current_date();
 
-char * filter_out_same_origins(char * objects, char * object);
+char * UP_filter_out_same_origins(char * objects, char * object);
+
+int UP_is_object(const char * arg);
 
 #ifdef __cplusplus
 }
