@@ -35,7 +35,11 @@
 #include "AU_util.h"
 #include "ack.h"
 #define private private_xx
+#define or or_xx
+#define not not_xx
 #include "mm.h"
+#undef not
+#undef or
 #include "mysql_driver.h"
 //#include "mail_parser.h"
 #undef private
@@ -62,6 +66,7 @@ typedef enum {
   UP_ANE, /* AUTO NIC hdl error */
   UP_FWD, /* mntner or as-block creation will be forwarded to <HUMAILBOX> */
   UP_SYN, /* syntax error in the object */
+  UP_NAM, /* name of a person/role object cannot be changed */
   UP_INT  /* internal error */
 
 } return_codes;
