@@ -1,4 +1,4 @@
-//  $Id: schema_rpsl.cc,v 1.10 2001/02/27 10:08:52 engin Exp $
+//  $Id: schema_rpsl.cc,v 1.20 2001/08/02 08:53:33 engin Exp $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -59,7 +59,6 @@ char Schema::dictionary_text[] = "";
 attr:  notify           syntax(email),                                         optional,  multiple
 attr:  remarks                                                                 optional,  multiple
 attr:  source           syntax(special,source),                                mandatory, single,   internal
-attr:  integrity        syntax(rpsl_word),                                     optional, single,   internal
 attr:  changed          syntax(special, changed),                              mandatory,  multiple
 attr:  delete                                                                  optional,  single, deleted
 attr:  override                                                                optional,  single"
@@ -75,7 +74,7 @@ attr:  source           syntax(rpsl_word),                                     m
 attr:  integrity        syntax(rpsl_word),                                     optional, single,   internal
 attr:  changed          optional,  multiple
 attr:  deleted                                                                 optional,  single, deleted  
-attr:  descr                                                                   mandatory, single
+attr:  descr                                                                   mandatory, single 
 attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
 attr:  tech-c                                                                  mandatory, multiple, lookup
 attr:  admin-c                                                                 optional,  multiple, lookup
@@ -93,12 +92,13 @@ typedef: as_number-as_set_name union as_number, as_set_name
 typedef: ListOfas_number list of as_number
 typedef: ListOfas_number-as_set_name list of as_number-as_set_name
 typedef: ListOfas_set_name  list of as_set_name
-typedef: ListOfroute_set_name  list of route_set_name
+typedef: ListOfroute_set_name  list[1 : 65535] of route_set_name
 typedef: as_number-as_set_name-route_set_name-IPv4Prefix
          union as_number, as_set_name, route_set_name, Address_Prefix
 typedef: ListOfas_number-as_set_name-route_set_name-IPv4Prefix
          list of as_number-as_set_name-route_set_name-IPv4Prefix
 typedef: ListOfrpsl_word List of rpsl_word
+typedef: listofrpsl_word_non_empty list[1 : 65535] of rpsl_word
 rp-attribute: # preference, smaller values represent higher preferences
               pref
               operator=(integer[0, 65535])  
@@ -175,10 +175,10 @@ attr:  upd-to           syntax(email),                                         m
 attr:  auth                                                                    mandatory, multiple
 attr:  mnt-nfy          syntax(email),                                         optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                optional,  multiple, lookup
-attr:  referral-by      syntax(rpsl_word),                                     optional, single 
+attr:  referral-by      syntax(rpsl_word),                                     mandatory, single 
 attr:  auth-override    syntax(integer),                                       optional, single
 
 class: person
@@ -188,17 +188,17 @@ attr:  address                                                                 m
 attr:  phone            syntax(special,phone),                                 mandatory, multiple
 attr:  fax-no           syntax(special,phone),                                 optional,  multiple
 attr:  e-mail           syntax(email),                                         optional,  multiple, lookup           " CMN_ATTRS "
-attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple, lookup
 
 class: role
 attr:  role             syntax(special,person),                                mandatory, single,   lookup
 attr:  nic-hdl          syntax(special,nichdl),                                mandatory, single,   key
 attr:  address                                                                 mandatory, multiple
-attr:  phone            syntax(special,phone),                                 mandatory, multiple
+attr:  phone            syntax(special,phone),                                 optional, multiple
 attr:  fax-no           syntax(special,phone),                                 optional,  multiple
 attr:  e-mail           syntax(email),                                         mandatory, multiple, lookup
 attr:  trouble                                                                 optional,  multiple                   " CMN_ATTRS "
-attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
@@ -212,71 +212,71 @@ attr:  aggr-bndry       syntax(special, aggr-bndry),                           o
 attr:  aggr-mtd         syntax(special, aggr-mtd),                             optional,  single
 attr:  export-comps     syntax(special, filter),                               optional,  single
 attr:  holes            syntax(ListOfIPv4Prefix),                              optional,  multiple                   " CMN_ATTRS "
-attr:  descr                                                                   mandatory, single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
-attr:  admin-c          syntax(special,nichdl),                                optional,  multiple, lookup
-attr:  tech-c           syntax(special,nichdl),                                optional,  multiple, lookup
-attr:  cross-nfy        syntax(list of rpsl_word),                             optional,  multiple
-attr:  cross-mnt        syntax(list of rpsl_word),                             optional,  multiple
+attr:  descr                                                                   mandatory, multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
+attr:  cross-nfy        syntax(special,nichdl),                                optional,  multiple
+attr:  cross-mnt        syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple
+attr:  mnt-routes       syntax(rpsl_word),                                       optional,  multiple
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple
 
 class: route-set
 attr:  route-set        syntax(route_set_name),                                mandatory, single,   key
 attr:  members          syntax(special, rs-members),                           optional,  multiple, lookup 
-attr:  mbrs-by-ref      syntax(list of rpsl_Word),                             optional,  multiple, lookup           " CMN_ATTRS "
-attr:  descr                                                                   mandatory, single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  mbrs-by-ref      syntax(list [1 : 65535] of rpsl_Word),                             optional,  multiple, lookup           " CMN_ATTRS "
+attr:  descr                                                                   mandatory, multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
 class: as-set
 attr:  as-set           syntax(as_set_name),                                   mandatory, single,   key
-attr:  members          syntax(list of union as_number, as_set_name),          optional,  multiple, lookup     
-attr:  mbrs-by-ref      syntax(list of rpsl_word),                             optional,  multiple, lookup           " CMN_ATTRS "
-attr:  descr                                                                   mandatory, single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  members          syntax(list [1 : 65535] of union as_number, as_set_name),          optional,  multiple, lookup     
+attr:  mbrs-by-ref      syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple, lookup           " CMN_ATTRS "
+attr:  descr                                                                   mandatory, multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
 class: rtr-set
 attr:  rtr-set        syntax(rtr_set_name),                                       mandatory, single,   key
-attr:  members        syntax(list of union rtr_set_name, dns_name, ipv4_address), optional,  multiple, lookup 
-attr:  mbrs-by-ref    syntax(list of rpsl_Word),                               	  optional,  multiple, lookup           " CMN_ATTRS "
-attr:  descr                                                                   	  mandatory, single
-attr:  mnt-by         syntax(list of rpsl_word),                               	  mandatory, multiple, lookup
+attr:  members        syntax(list [1 : 65535] of union rtr_set_name, dns_name, ipv4_address), optional,  multiple, lookup 
+attr:  mbrs-by-ref    syntax(list [1 : 65535] of rpsl_Word),                               	  optional,  multiple, lookup           " CMN_ATTRS "
+attr:  descr                                                                   	  mandatory, multiple 
+attr:  mnt-by         syntax(list [1 : 65535] of rpsl_word),                               	  mandatory, multiple, lookup
 attr:  admin-c        syntax(special,nichdl),                                  	  mandatory, multiple, lookup
 attr:  tech-c         syntax(special,nichdl),                                  	  mandatory, multiple, lookup
 
 class: peering-set
 attr:  peering-set    syntax(peering_set_name),                                   mandatory, single,   key
 attr:  peering        syntax(special, peering),                                   mandatory, multiple                   " CMN_ATTRS "
-attr:  descr                                                                   	  mandatory, single
-attr:  mnt-by         syntax(list of rpsl_word),                               	  mandatory, multiple, lookup
+attr:  descr                                                                   	  mandatory, multiple 
+attr:  mnt-by         syntax(list [1 : 65535] of rpsl_word),                               	  mandatory, multiple, lookup
 attr:  admin-c        syntax(special,nichdl),                                 	  mandatory, multiple, lookup
 attr:  tech-c         syntax(special,nichdl),                                  	  mandatory, multiple, lookup
 
 class: filter-set
 attr:  filter-set       syntax(filter_set_name),                               mandatory, single,   key
 attr:  filter           syntax(special, filter),                               mandatory, single                       " CMN_ATTRS "
-attr:  descr                                                                   mandatory, single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  descr                                                                   mandatory, multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
 class: aut-num
 attr:  aut-num          syntax(as_number),                                     mandatory, single,   key
-attr:  as-name          syntax(rpsl_word),                                     optional, single,   lookup
-attr:  member-of        syntax(List Of AS_set_name),                           optional,  multiple, lookup
+attr:  as-name          syntax(rpsl_word),                                     mandatory, single,   lookup
+attr:  member-of        syntax(List [1 : 65535] Of AS_set_name),                           optional,  multiple, lookup
 attr:  import           syntax(special,import),                                optional,  multiple
 attr:  export           syntax(special,export),                                optional,  multiple
 attr:  default          syntax(special,default),                               optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
-attr:  mnt-routes       syntax(special, mnt-routes),                           optional,  multiple, lookup
-attr:  mnt-lower        syntax(list of rpsl_word),                             optional,  multiple
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
+attr:  mnt-routes       syntax(rpsl_word),                           optional,  multiple, lookup
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
-attr:  cross-nfy        syntax(list of rpsl_word),                             optional,  multiple
-attr:  cross-mnt        syntax(list of rpsl_word),                             optional,  multiple
+attr:  cross-nfy        syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple
+attr:  cross-mnt        syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple
 
 class: inet-rtr
 attr:  inet-rtr         syntax(dns_name),                                      mandatory, single,   key
@@ -286,7 +286,7 @@ attr:  ifaddr           syntax(special,ifaddr),                                m
 attr:  peer             syntax(special,peer),                                  optional,  multiple                   " CMN_ATTRS "
 attr:  member-of        syntax(List Of rtr_set_name),                          optional,  multiple, lookup
 attr:  descr                                                                   optional,  multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
@@ -294,12 +294,12 @@ class: inetnum
 attr:  inetnum          syntax(range of ipv4_address),                         mandatory, single,   key
 attr:  netname          syntax(rpsl_word),                                     mandatory, single,   lookup
 attr:  country          syntax(special, country),                              mandatory, multiple
-attr:  rev-srv                                                                 optional,  multiple, lookup
+attr:  rev-srv          syntax(list [1 : 65535] of union dns_name, rpsl_word, ipv4_address),   optional,  multiple, lookup
 attr:  status           syntax(special,status_inet),                           mandatory, single
-attr:  mnt-routes       syntax(special, mnt-routes),                           optional, multiple 
-attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple                   " CMN_ATTRS "
+attr:  mnt-routes       syntax(rpsl_word),                           optional, multiple 
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                               optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory,  multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
@@ -307,24 +307,24 @@ class: inet6num
 attr:  inet6num          syntax(ipv6_prefix),                                  mandatory, single,   key
 attr:  netname           syntax(rpsl_word),                                    mandatory, single,   lookup
 attr:  country           syntax(special, country),                             mandatory, multiple
-attr:  rev-srv                                                                 optional,  multiple, lookup
+attr:  rev-srv           syntax(list [1 : 65535] of union dns_name, rpsl_word),  optional,  multiple, lookup
 attr:  status                                                                  optional, generated, single
-attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple                   " CMN_ATTRS "
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                               optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory,  multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
 class: domain
 attr:  domain           syntax(union dns_name, rpsl_word),                     mandatory, single,   key
-attr:  sub-dom                                                                 optional,  multiple, lookup
+attr:  sub-dom          syntax(list [1 : 65535] of union dns_name, rpsl_word),  optional,  multiple, lookup
 attr:  dom-net                                                                 optional,  multiple
 attr:  zone-c          syntax(special,nichdl),                                 mandatory, multiple, lookup
-attr:  nserver                                                                 optional,  multiple, lookup
+attr:  nserver         syntax(list [1 : 65535] of union dns_name, rpsl_word, ipv4_address),   optional,  multiple, lookup
 attr:  refer           syntax(special, refer),    optional, single
-attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple                   " CMN_ATTRS "
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                               optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, multiple 
-attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             optional,  multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
@@ -332,15 +332,15 @@ class: limerick
 attr:  limerick                                                                mandatory, single,   key
 attr:  text                                                                    mandatory, multiple
 attr:  author          syntax(special,nichdl),                                 mandatory, multiple, lookup           " CMN_ATTRS "
-attr:  descr                                                                   optional,  single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory, multiple, lookup
+attr:  descr                                                                   optional,  multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory, multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 
 class: as-block
-attr:  as-block         syntax(union as_number, range of as_number),           mandatory, single,   key
-attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple                   " CMN_ATTRS "
-attr:  descr                                                                   mandatory, single
-attr:  mnt-by           syntax(list of rpsl_word),                             mandatory,  multiple, lookup
+attr:  as-block         syntax(range of as_number),           mandatory, single,   key
+attr:  mnt-lower        syntax(list [1 : 65535] of rpsl_word),                               optional,  multiple                   " CMN_ATTRS "
+attr:  descr                                                                   optional, multiple 
+attr:  mnt-by           syntax(list [1 : 65535] of rpsl_word),                             mandatory,  multiple, lookup
 attr:  admin-c          syntax(special,nichdl),                                mandatory, multiple, lookup
 attr:  tech-c           syntax(special,nichdl),                                mandatory, multiple, lookup
 
@@ -350,24 +350,7 @@ attr:  method         generated, optional, single,      syntax(rpsl_word)
 attr:  owner          generated, optional, multiple
 attr:  fingerpr       generated, optional, single
 attr:  certif         mandatory, multiple                        " CMN_ATTRS "
-attr:  mnt-by         mandatory, multiple, lookup,      syntax(list of rpsl_word)
-
-class: peval   
-attr:  peval            syntax(special,filter),                                 optional,  single
-
-class: repository
-attr:  repository           mandatory,  single,  key,   syntax(rpsl_word)
-attr:  query-address        mandatory,  multiple
-attr:  response-auth-type   mandatory,  multiple
-attr:  submit-address       mandatory,  multiple
-attr:  submit-auth-type     mandatory,  multiple
-attr:  repository-cert      mandatory,  multiple
-attr:  expire               mandatory,  single
-attr:  heartbeat-interval   mandatory,  single
-attr:  descr                optional,   multiple
-attr:  admin-c              mandatory,  multiple, lookup
-attr:  tech-c               mandatory,  multiple, lookup
-attr:  mnt-by               mandatory,  multiple, lookup " CMN_ATTRS "
+attr:  mnt-by         mandatory, multiple, lookup,      syntax(list [1 : 65535] of rpsl_word)
 ";
 
 void Schema::addClass(AttrClass *clss) {
