@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.24 $
+  $Revision: 1.26 $
 
   which_keytypes:  Determine which keys to look for.
   
@@ -27,17 +27,15 @@
   AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
+
+#define  WK_IMPL
+#include "rip.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <strings.h>
 #include <glib.h>
 #include <pthread.h>
-
-#include "bitmask.h"
-#include "memwrap.h"
-
-#define  WK_IMPL
-#include "which_keytypes.h"
 #include <regex.h>
 
 #define DOMAINNAME "^[ ]*[a-zA-Z0-9-]*(\\.[a-zA-Z0-9-]+)*[ ]*$"
@@ -256,7 +254,7 @@ WK_to_string (mask_t wk)
 mask_t 
 WK_new (char *key) 
 {
-  static pthread_once_t once_control = { PTHREAD_ONCE_INIT };
+  static pthread_once_t once_control = PTHREAD_ONCE_INIT;
 
   mask_t wk; 
   int i;
